
import { ButtonOneEngineering } from "../components/Buttons";
import { openElement } from "../utils/openElement";
import { H2, H3, H4, H5, PhilipH3 } from "../components/Headings";
import { useTabNavigation } from "../utils/TabNavigation";
import { Collapsible } from "../components/Collapsible";
import { useNavigation } from "../utils";
import { TabScrollLink } from "../components/Link";
import { InfoBox } from "../components/Boxes";
import { DownloadLink } from "../components/Buttons";
import { Section } from "../components/sections";
import EngTrfsources from "../sources/eng-trf-sources";
import EngRepsources from "../sources/eng-reporter-sources";
import EngPEsystems from "../sources/eng-pe-sources";
import EngPegsources from "../sources/eng-peg-sources";
import EngNicksources from "../sources/eng-nickases-sources";
import EngDelsources from "../sources/eng-delivery-sources";
import { TwoLinePDF, PDF } from "../components/Pdfs";


export function Engineering() {
   useTabNavigation();
   const {goToPagesAndOpenTab} = useNavigation ();
   const {goToPageAndScroll} = useNavigation();
   const {goToPageWithTabAndScroll} = useNavigation();
    return (
      <>
        <div className="row mt-4">
          <div className="col">
          <br/> <br/> <br/> 
            <div id="tab-our-cycle" className="enginneeringtab" style={{display: "block"}}>
               <section > <br id="obenengineering"/>
                  <div className="eng-box box" >
                     <H2 text="Our cycle" id="our-cycle-header"></H2>
                     <p>
                        In the course of our project, innovative thoughts were taken up, rejected, elaborated, discussed and tested. On this page we present a selection of ideas that occupied us the most in the last month. Our trains of thought are represented in form of iterations of engineering cycles. Each engineering cycle is comprised of four steps:
                     </p>
                     <ul>
                        <li>
                           <b>Design</b>: In this step the motivation or problem, that the individual iteration addresses, is mentioned. A theoretical approach addressing the motivation is explained.
                        </li>
                        <li>
                           <b>Build</b>: The practical examination of the theoretical plan described in the design section is executed, e. g. by planning an experiment, by creating a construct in silico, by cloning.
                        </li>
                        <li>
                           <b>Test</b>: The initial design is tested, either by conducting an experiment, testing a design in silico, e. g. by modeling, refuting ideas based on new input or background research or discussing approaches with an expert. 
                        </li>
                        <li>
                           <b>Learn</b>: In this last section, test results are discussed and insights gained in testing the design are formulated.
                        </li>
                     </ul>
                  </div>
                  
                  <br/>
                  <div className="row">
                     <div className="col">
                     
                     </div>
                     <div className="col button-left">
                        <div className="right"><ButtonOneEngineering label="Next" open="reporter" scrollToId="reporter-header"/></div>
                     </div>
                  </div>
               </section>
            </div>

            <div className="enginneeringtab" id="tab-reporter" style={{display: "none"}}>
            <section id="reporter sec" >
                  <div className="eng-box box" >
                     <H2 id="reporter-header" text="Prime Editing Reporter"></H2>
                     <p>Prime editing is a is a very precise and safe method. However, depending on the genomic locus targeted, the editing efficiency can be very low. The cystic fibrosis causing CFTR F508del mutation is, as <a onClick={() => goToPagesAndOpenTab('mattijsinv', '/human-practices')}> Mattijs Bulcaen </a>  stated in our interview, one of, if not the most obvious application of prime editing, considering the large amount of people affected. The lack of publications addressing CFTR target implied, that the mutation might be particularly hard to edit. At low editing efficiency, successful edits are hard, if not impossible to distinguish from the background noise using conventional methods like sanger sequencing or qPCR. As a basis to effectively test our approach and screen for working pegRNAs, we needed a highly sensitive method of detection with as little noise as possible to optimize our prime editing approach for genomic CFTR targeting.</p>
                  </div>
                  <div className="box" >
                     <p id="rep1">
                        <H3 text="A Fluorescence Reporter" id="rep1head"/>
                        <H4 text="Design" id="design-head"/>
                        <p>
                           We reasoned that the easiest way of detecting DNA changes in a cell would be fluorescence. Our initial idea was to create pegRNAs targeting the coding sequence of a fluorescent protein, that would introduce a mutation resulting in a different emission, giving easily detectable feedback of correct editing. The original Aequorea victoria GFP protein differs from avGFP(Y66W), emitting light in a wavelength of around 509 nm (cyan), and avGFP(Y66H), emitting light in a wavelength of around 448 nm (blue) by only one amino acid substitution each.<TabScrollLink tab="tab-reporter" num="1" scrollId="desc-1"/> Prime editing could therefore be visualized by facilitating these substitutions with a prime editor.
                        </p>
                        <H4 text="Build" id="build-head"/>
                        <p>
                           To this end, the wild-type and edited versions of the avGFP were put in contrast and we started searching for potential pegRNAs for editing one into the other.
                        </p>
                        <figure>
                           <img src="https://static.igem.wiki/teams/5247/engineering-cycle/rep-it1.svg" alt="Illustration of fluorescence wavelength change reporter"/>  
                           <figcaption><b>Figure 1: Illustration of a reporter system based on the introduction of a single amino acid substitution into GFP plasmids transformed into HEK293 cells changing the emission spectrum in a detectable way.</b> </figcaption>
                        </figure>
                        <H4 text="Test" id="test-head"/>
                        <p>
                           When trying to find protospacers for Cas9 and other possible nickases<a onClick={() => goToPagesAndOpenTab('nickase', '/engineering')}> nickases </a> , we noticed, that the locus of the mutations is too far away from any SpuFz1 TAM sequences. Additionally, the applicability of insights gained through pegRNA optimization in this locus to CFTR editing would also be very limited due to the vast differences in the sequence of protospacer and surrounding genomic region. Additionally, we learned from our interview with <a onClick={() => goToPagesAndOpenTab('mattijsinv', '/human-practices')}> Mattijs Bulcaen </a> that the type of edit (insertion, substitution or deletion) significantly impacts editing efficiency. A mutation changing GFP to BFP would have to be a substitution instead of the three-nucleotide insertion needed to correct CFTR F508del.
                        </p>
                        <H4 text="Learn" id="learn-head"/>
                        <p>
                           From our observations we learned that a reporter system is only of use, if it can really mimic the genomic target of choice. The adjustments to be made to create a pegRNA targeting the genomic target from a pegRNA targeting the reporter should be as minor as possible. This includes a similar spacer and a similar edit to be made.
                        </p>
                     </p>
                  </div>
                  <div className="box" >
                     <p id="rep2">
                        <H3 text="Proof of Concept for PEAR" id="rep2head"/>
                        <H4 text="Design" id="design-head"/>
                        <p>
                           After extensive research we came across the prime editor activity reporter (PEAR) created by Simon et al. (2022)<TabScrollLink tab="tab-reporter" num="2" scrollId="desc-2"/>, which is the template our modified reporter plasmid is based on. The PEAR plasmid contains an eGFP coding sequence with an intron derived from the mouse Vim gene. If the intron is removed during RNA splicing, the two exons form a continuous open reading frame. By mutating the 5’ splicing signal, a target is created which, upon correct editing, leads to a gain-of-function. The resulting fluorescence can be imaged using confocal microscopy or quantified by means of flow cytometry. Notably, the area downstream of the 5’ splice signal is intronic, and thus can be edited without any impact on the coding sequence. Additionally, Simon et al. showed, that “efficiency of prime editing to modify PEAR plasmids is governed by the same factors as prime editing in genomic context”. We reasoned that this system might be flexible, and sensitive enough to build our optimizations strategies upon.
                        </p>
                        <H4 text="Build" id="build-head"/>
                        <p>
                           Since none of us had any experience in prime editing before our project, we wanted to test whether we can facilitate prime editing in the first place. To do this and also assess the functionality of the PEAR system, we set up a proof of concept using the PEAR 2in1 system. This plasmid includes not only the eGFP with and intron and disrupted 5’ splice site, but also a pegRNA expression cassette. The pegRNA is designed in a way that, in combination with a prime editing protein complex, corrects the disrupted splicing signal.
                        </p>
                        <H4 text="Test" id="test-head"/>
                        <p>
                           In the experiment, we transfected HEK293 cells (as recommended by <a onClick={() => goToPagesAndOpenTab('mattijsinv', '/human-practices')}> Mattijs Bulcaen </a>) with the <a onClick={() => goToPageWithTabAndScroll ({scrollToId: 'pe1', path: '/engineering', tabId: 'pe-systems' })}>pCMV-PE2 prime editor</a> plasmid and the pDAS12489_PEAR-GFP_2in1_2.0 mentioned above. Our first proof of concept succeeded as we could see fluorescent cells 72 h after transfection. In contrast, negative controls with only one of the plasmids transfected did not show any fluorescence. However, the transfection efficiency in our initial test runs was quite low, as indicated by a technical positive control.
                        </p>
                        <figure>
                           <img src="https://static.igem.wiki/teams/5247/engineering-cycle/rep-it2.svg" alt="Illustration of the proof of concept using the PEAR2in1 system"/>  
                           <figcaption><b>Figure 2:</b> Illustration of the proof of concept experiment. HEK293 cells transiently transformed with the pDas12189_PEAR-GFP_2in1_2.0 plasmid on the left side show fluorescence after transformation with a prime editor expression plasmid.</figcaption>
                        </figure>
                        <H4 text="Learn" id="learn-head"/>
                        <p>
                           This proved, that not only we were able to use prime editing in our model, but also that the PEAR reporter system can report successful prime editing. Though this was a very promising start, further steps had to be taken to enable context specific testing of prime editing. Firstly, the transfection efficiency had to be improved (see <a onClick={() => goToPageWithTabAndScroll ({scrollToId: 'transfection-header', path: '/engineering', tabId: 'transfection' })}> Transfection Optimization</a>). Secondly, the reporter had to be modified in a way that resembles the genomic CFTR target.
                        </p>
                     </p>
                  </div>
                  <div className="box" >
                     <p id="rep3">
                        <H3 text="Contextualization of PEAR" id="rep3head"/>
                        <H4 text="Design" id="design-head"/>
                        <p>
                           The original PEAR plasmid pDAS12124_PEAR-GFP-preedited that we bought from AddGene represents, as the name suggests, how the reporter should look like after successful editing and can thus be used as a positive control and for normalization. To alter the PEAR plasmid so that it mimics the mutated genomic CFTR target, we first analyzed the region surrounding CFTR F508del mutation. As the mutation is a three base pair deletion, we introduced the very same at the 5’ splicing signal. For this modification to reliably disrupt intron splicing and thus eGFP expression, we effectively removed the GT bases of the intronic 5’ splice donor site as well as the preceding, exonic G base of the 5’ flanking sequence. Secondly, we replaced the intronic region downstream of the four base pair 3’ flanking region with the respective sequence from the CFTR locus. This 27 bp substitute included a PAM sequence, an entire spacer as well as four additional base pairs in between present in the original gene sequence. Lastly, we introduced silent mutations upstream of the 5’ flanking sequence that lowered the GC content. This was to mimic the AT-rich region preceding the F508del mutation in the CFTR gene. This reveals one of the necessary shortcomings of this reporter: Edits upstream of the 5’ donor site are heavily restricted by the eGFP coding sequence.
                        </p>
                        <figure>
                           <img src="https://static.igem.wiki/teams/5247/engineering-cycle/rep-it3_strategy.svg" alt="Modification strategy for creation of the pPEAR_CFTR plasmid"/>  
                           <figcaption><b>Figure 3:</b> Illustration of the modification strategy for the pPEAR_CFTR reporter. The pDAS12124_PEAR-GFP-preedited plasmid was modified by introducing a 3 bp deletion resembling the F508del mutation, inserting a 27 bp sequence from the genomic CFTR target including PAM and protospacer sequence as well as making silent edits to account for the AT-rich region upstream of the mutation.</figcaption>
                        </figure>
                        <H4 text="Build" id="build-head"/>
                        <p>
                           We constructed the reporter system by first analyzing the original plasmid to identify appropriate restriction sites. We then digested the plasmid backbone and cloned in a gene synthesis fragment ordered at IDT containing the edits via Gibson Assembly cloning. The correct cloning was validated first by colony PCR and then by sequencing the regions of the plasmid containing the cloning sites and our modifications.
                        </p>
                        <H4 text="Test" id="test-head"/>
                        <p>
                           We evaluated the functionality of our reporter system by co-transfecting our reporter construct with a pCMV-PE2 prime editor plasmid as well as a plasmid expressing pegRNA that targeted our reporter (see <a onClick={() => goToPagesAndOpenTab('pegrna', '/engineering')}> pegRNA engineering cycle </a>) into HEK293 cells. After 72 h we saw a significant number of cells showing fluorescence. 
                        </p>
                        <p>
                           Additionally, for positive controls we transfected a technical control plasmid as well the unmodified pDAS12124_PEAR-GFP-preedited plasmid, which could be used to determine the transfection efficiency as well as normalize the editing efficiency. As negative controls, our modified plasmid, pCMV-PE2 and the pegRNA plasmid were transfected. The positive controls showed fluorescence, while the negative control did not. 
                        </p>
                        <figure>
                           <img src="https://static.igem.wiki/teams/5247/engineering-cycle/rep-it3.svg" alt="Illustration of pegRNA testing using the pPEAR_CFTR system"/>  
                           <figcaption><b>Figure 4:</b> Illustration of the pegRNA testing using the pPEAR_CFTR system. HEK293 cells transiently transformed with the pPEAR_CFTR plasmid (in the middle) show fluorescence after transformation with a prime editor and a reporter-specific pegRNA expression plasmid. The pDAS12124_PEAR-GFP-preedited is used as an internal positive control and for normalization.</figcaption>
                        </figure>
                        <H4 text="Learn" id="learn-head"/>
                        <p>
                           Our results demonstrate three things: Firstly, the original pDAS12124_PEAR-GFP-preedited plasmid leads to undisrupted expression of eGFP in the transfected cells. Secondly, the modifications that we made to create our own, context specific PEAR plasmid prevented proper expression of eGFP in transfected, unedited cells as planned and notably with no apparent noise. The last and most important insight gained was, that editing of the reporter plasmid using respective pegRNAs successfully restores eGFP expression, proving that our reporter works as intended.
                        </p>
                        <p>
                           <b>This achievement formed a convenient basis for the following optimization of prime editing in the CFTR F508del locus for us as well as other research groups.</b>
                        </p>
                     </p>
                  </div>
                  <div className="box" >
                     <p id="rep4">
                        <H3 text="Application in epithelial Cells" id="rep4head"/>
                        <H4 text="Design" id="design-head"/>
                        <p>
                           Although we could show that our PEAR reporter plasmid works in a HEK cell model, according to <a onClick={() => goToPagesAndOpenTab('ignatova', '/human-practices')}> Prof.Dr. Zoya Ignatova </a> insights gained here might still not entirely transfer to cells actively expressing CFTR. As recommended, we applied our reporter to a system closer to a therapeutic target <a onClick={() => goToPageAndScroll ('Cell Culture2H', '/materials-methods')}>CFBE41o-</a>. The cells are derived from bronchial epithelial cells of a cystic fibrosis patient and are homozygous for CFTR F508del.
                        </p>
                        <H4 text="Build" id="build-head"/>
                        <p>
                           For experimenting in CFBE41o- cells, the same reporter construct was used as for the HEK293 test. However, we used a different prime editor (pCMV-PE6c, see prime editing systems engineering cycle<a onClick={() => goToPagesAndOpenTab('pe-systems', '/engineering')}> prime editing systems circle </a>), and only pegRNAs were used, that proved the most efficient in preceding experiments (see <a onClick={() => goToPagesAndOpenTab('pegrna', '/engineering')}> pegRNA engineering cycle </a>).
                        </p>
                        <H4 text="Test" id="test-head"/>
                        <p>
                           Similar to the previous cycle, we evaluated the functionality of our reporter system by co-transfecting our reporter construct with a pCMV-PE6c prime editor plasmid as well as a plasmid expressing pegRNA that targeted our reporter this time into CFBE41o- cells. After 72 h we saw a significant number of cells showing fluorescence. 
                        </p>
                        <p>
                           Like with the experiments in HEK cells, we transfected a technical control plasmid as well the unmodified pDAS12124_PEAR-GFP-preedited plasmid as positive controls and our modified plasmid, pCMV-PE6c and the pegRNA plasmid individually as negative controls. Again, the positive controls showed solid fluorescence, while the negative control did not. 
                        </p>
                        <figure>
                           <img src="https://static.igem.wiki/teams/5247/engineering-cycle/rep-it5.svg" alt="Illustration of applying the pPEAR_CFTR system to lung epithelial cell lines"/>  
                           <figcaption><b>Figure 5:</b> Illustration of the pegRNA testing using the pPEAR_CFTR system. CFBE41o- cells transiently transformed with the pPEAR_CFTR plasmid (in the middle) show fluorescence after transformation with a prime editor and a reporter-specific pegRNA expression plasmid. The pDAS12124_PEAR-GFP-preedited is used as an internal positive control and for normalization.</figcaption>
                        </figure>
                        <H4 text="Learn" id="learn-head"/>
                        <p>
                           This experiment confirms that our reporter can not only be used in cell lines distantly related to patient cells of interest, in our case HEK203 cells, but also works in cells actively expressing CFTR and carrying the mutation. The reporter still showed no noise.
                        </p>
                     </p>
                  </div>
                  <div className="box" >
                     <p id="rep5">
                        <H3 text="Application in Primary Cells" id="rep5head"/>
                        <H4 text="Design" id="design-head"/>
                        <p>
                           The model closest to application in actual patient cells are human derived primary cells. For our last test of our modified PEAR reporter, we thus chose to use <a onClick={() => goToPageAndScroll ('Cell Culture3H', '/materials-methods')}>human nasal epithelial cells</a> derived from members of our team.
                        </p>
                        <H4 text="Build" id="build-head"/>
                        <p>
                           For testing our reporter in the human nasal epithelial cells, the same constructs have been used as in the previous iteration with CFBE41o- cells.
                        </p>
                        <H4 text="Test" id="test-head"/>
                        <p>
                           The experimental setup for this experiment was a scaled down version of the previous cycle with the only altered variable being the cells transfected. In this case, we did not observe any fluorescence, neither in the tested cells, nor the technical or pDAS12124_PEAR-GFP-preedited positive controls.
                        </p>
                        <H4 text="Learn" id="learn-head"/>
                        <p>
                           In this last experiment, the negative technical positive control implies a failed transfection of the cells. Thus, this attempt did not allow to draw any conclusion regarding the function of our reporter in primary cells. The experiment is to be repeated in the future.
                        </p>
                     </p>
                  </div>
                  <div className="box" >
                     <p id="rep6">
                        <H3 text="Outlook" id="rep6head"/>
                        <p>
                           Our CFTR contextualized PEAR reporter proved to consistently allow detection of prime editing without notable noise, laying the foundation for optimization of existing and testing of new prime editing systems. Although very versatile in the context of targeting CFTR F508del with the <a onClick={() => goToPagesAndOpenTab('pegRNA-genau-collapsible', '/description')}>spacer of our choice</a>, a wider applicability to other genomic targets and other possible prime editor variants working differently than Cas9-based systems would be favorable. In the original PEAR plasmid however, modification of variable region is quite impractical. Also, as a part the eGFP is RCF[1000] but not RCF[10] BioBrick standard conform and hardly compatible with other parts like our <a onClick={() => goToPageWithTabAndScroll ({scrollToId: 'pe3', path: '/engineering', tabId: 'pe-systems'})}>PreCyse cassette</a>.
                        </p>
                        <H4 text="Design" id="design-head"/>
                        <p>
                           This is why, as an outlook and contribution for future iGEM teams, we aim to create a more modular and compatible part similar to our PreCyse Casette. For this we made use of the experience gained when cloning pegRNAs. An oligonucleotide-based golden gate cloning site in the region of interest surrounding the 5’ splice donor site allows for cheap and convenient modification of the sequence. The area between the TypeIIS restriction sites is designed as a dropout cassette coding for a fluorescence marker expressed in E. coli, that enables rapid screening for transformants containing correctly digested plasmid backbones.
                        </p>
                        {/* <H4 text="Build" id="build-head"/>
                        <p>

                        </p>
                        <H4 text="Test" id="test-head"/>
                        <p>

                        </p>
                        <H4 text="Learn" id="learn-head"/>
                        <p>

                        </p> */}
                     </p>
                  </div>
                  <Section title="References" id="references">
                     <EngRepsources/>
                  </Section>
                  <br/>
                  <div className="row ">
                     <div className="col">
                     <div className="left"><ButtonOneEngineering label="Previous" open="our-cycle" scrollToId="our-cycle-header"/></div>
                     </div>
                     <div className="col button-left">
                        <div className="right"><ButtonOneEngineering label="Next" open="transfection" scrollToId="transfection-header"/></div>
                     </div>
                  </div>
               </section>
            </div>

            <div id="tab-transfection" className="enginneeringtab" style={{display: "none"}}>
               <section  >
                  <div className="eng-box box" >
                     <H2 id="transfection-header" text="Optimization of Transfection"></H2>
                     <p>
                        To test prime editors, a reliable model system is required. HEK293 cells are a human derived cell line and widely used in a variety of fields in biology<TabScrollLink tab="tab-transfection" num="1" scrollId="desc-1"/>. Apart from easy handling and comparatively easy transfection, they have, as we found out in our exchange with  <a onClick={() => goToPagesAndOpenTab('mattijsinv', '/human-practices')}>Mattijs Bulcaen</a>, one advantage over other models: They are naturally impaired in DNA repair mechanisms and therefore easier to edit. To properly compare editing efficiencies, a high transfection efficiency is of utmost importance. This engineering cycle focuses on our work in simulating prime editing using the PEAR reporter system<TabScrollLink tab="tab-transfection" num="2" scrollId="desc-2"/> and optimizing transfection protocols.
                     </p>
                  </div>
                  <div className="box" >
                     <p id="trf1">
                        <H3 text="Test of Lipofectamine 2000" id="trf1head"/>
                        <H4 text="Design" id="text"/>
                        <p>
                           Before testing any of our mechanistic approaches, we had to examine whether we can facilitate and detect prime editing in the first place. During our research we eventually stumbled upon the PEAR reporter system (see <a onClick={() => goToPagesAndOpenTab('pegrna', '/engineering')}> pegRNA engineering cycle </a>)). The PEAR 2in1 plasmid reporter includes a GFP that is to be edited for sensitive prime editing detection, and a pegRNA expression cassette with a pegRNA targeting the plasmid itself. Having found a system capable of detecting even small-scale prime editing, the next step was to find transfection conditions that would work. In the literature, Lipofectamine is described as a common transfection agent.
                        </p>
                        <p>
                           Transfection with Lipofectamine 2000 was performed in accordance with the Anzalone protocol. However, the result was characterized by insufficient transfection efficiency.
                        </p>
                        <H4 text="Build" id="text"/>
                        <p>
                           Anzalone et al. 2019<TabScrollLink tab="tab-transfection" num="3" scrollId="desc-3"/> describe a transfection of prime-editing complexes with Lipofectamine 2000. 
                        </p>
                        <H4 text="Test" id="text"/>
                        <p>
                           Transfection with Lipofectamine 2000 was performed in accordance with the Anzalone protocol. However, the result was characterized by insufficient transfection efficiency.
                        </p>
                        <H4 text="Learn" id="text"/>
                        <p>
                           The low efficiency of Lipofectamine 2000 indicates that the product is not optimally suited to the specific conditions under consideration. In contrast, Lipofectamine 3000 is described in the literature as potentially more efficient.
                        </p>
                     </p>
                     
                  </div>
                  <div className="box" >
                     <p id="trf2">
                        <H3 text="Initial Test with Lipofectamine 3000" id="trf2head"/>
                        <H4 text="Design" id="text"/>
                        <p>
                           In light of the aforementioned findings, the decision was taken to test Lipofectamine 3000, given its reputation for greater efficiency. A new test design was devised, utilizing Lipofectamine 3000 with an equivalent quantity of DNA and modified transfection conditions.
                        </p>
                        <H4 text="Build" id="text"/>
                        <p>
                           In accordance with the established protocol, the recommended ratio of 1 µg DNA to 2 µl Lipofectamine 3000, as provided by ThermoFisher, was to be employed.
                        </p>
                        <H4 text="Test" id="text"/>
                        <p>
                           The objective of the experiment was to enhance the transfection efficiency of Lipofectamine 3000. The transfection protocol was conducted in accordance with the manufacturer's instructions (1 µg DNA, 2 µl Lipofectamine 3000 reagent).
                        </p>
                        <p>
                           The outcome revealed that despite the modification, the transfection efficiency remained inadequate, although a marginal improvement was discernible.
                        </p>
                        <H4 text="Learn" id="text"/>
                        <p>
                           Although a switch to Lipofectamine 3000 resulted in a marginal improvement, the efficiency fell short of expectations. This indicates that further optimization is required in terms of the amount of Lipofectamine and DNA, as well as the medium used.
                        </p>
                     </p>
                  </div>
                  <div className="box" >
                     <p id="trf3">
                        <H3 text="Optimization of DNA and Lipofectamine Volumes" id="trf3head"/>
                        <H4 text="Design" id="text"/>
                        <p>
                        In order to optimize the transfection process, a new optimization test was designed, which incorporated a variable design with regard to the quantity of Lipofectamine 3000 and DNA.
                        </p>
                        <H4 text="Build" id="text"/>
                        <p>
                        The protocol entailed the utilization of varying concentrations of Lipofectamine 3000, specifically 1 µl and 1.5 µl, with a DNA quantity of 1 µg or 0.5 µg. In this phase, we developed the transfection method with calcium chloride (CaCl2) as an alternative to conventional lipofectamine transfection. The aim was to test whether this more cost-effective method offers comparable transfection efficiency. Three different DNA concentrations were used to investigate the effect on transfection efficiency.
                        </p>    
                        <H4 text="Test" id="text"/>
                        <p>
                        To enhance transfection efficiency, optimization tests were conducted, in which the quantities of Lipofectamine and DNA were varied. The objective of this iteration was to find the optimal ratio of Lipofectamine 3000 to DNA. To this end, 1 µl and 1.5 µl of Lipofectamine 3000 at a DNA concentration of either 1 µg or 0.5 µg were compared with each other. In the next step, the tests were carried out with the different DNA concentrations using the CaCl2 transfection method. The transfection efficiencies were compared with those from the Lipofectamine transfection to determine whether the new method represents an improvement. 
                        </p>
                        <H4 text="Learn" id="text"/>
                        <p>
                        The experiment demonstrated that a quantity of 1 µl Lipofectamine 3000 was sufficient for successful transfection, and that increasing the quantity does not result in a notable difference. Additionally, the findings indicated that an amount of 1 µg DNA exhibited a higher efficiency than an amount of 0.5 µg DNA. It can be reasoned that additional factors may have contributed to the previously observed decline in transfection efficiency. One potential explanation is that the cells may have been in an excessively high passage level. It became clear from the tests that CaCl2 transfection did not deliver better results than Lipofectamine transfection. On the contrary, the efficiency was significantly lower, although the method is less expensive. This led to the realisation that the CaCl2 technique in this form was not a suitable alternative for our specific requirements. 
                        </p>
                        <p>
                           It can be reasonably deduced that the aforementioned factors may have contributed to the observed decline in transfection efficiency.
                        </p>
                     </p>
                  </div>
                  <div className="box" >
                     <p id="trf4">
                        <H3 text="Validation of optimized Protocol" id="trf4head"/>
                        <H4 text="Design" id="text"/>
                        <p>
                           The results obtained were used to develop an optimized protocol that takes into account both the concentration of Lipofectamine and the amount of DNA.
                        </p>
                        <H4 text="Build" id="text"/>
                        <p>
                           In subsequent research, a DNA quantity of 1 µg and a defined quantity of 1 µl of Lipofectamine 3000 will be utilized.
                        </p>
                        <H4 text="Test" id="text"/>
                        <p>
                           Following a series of optimizations, the proof of concept was conducted once more to confirm the efficacy of the optimized protocol. The objective was to perform the transfection with the final, optimized protocol. This protocol involved the utilization of 1 µl Lipofectamine 3000, 1 µg DNA, 2 µl Reagent 3000 and Opti-MEM as a medium. The outcomes were encouraging, as the transfection efficiency was markedly enhanced.
                        </p>
                        <H4 text="Learn" id="text"/>
                        <p>
                           The utilization of an optimized quantity of 1 µl Lipofectamine 3000, a defined quantity of DNA and the suitable Opti-MEM medium resulted in a notable enhancement in transfection efficiency. This substantiates the assertion that the aforementioned conditions constitute an optimal foundation for the transfection of HEK cells with the prime editing complex.
                        </p>
                     </p>
                  </div>
                  <Section title="References" id="references">
                     <EngTrfsources/>
                  </Section>
                  <br/>
                  <div className="row ">
                     <div className="col">
                     <div className="left"><ButtonOneEngineering label="Previous" open="reporter" scrollToId="reporter-header"/></div>
                     </div>
                     <div className="col button-left">
                        <div className="right"><ButtonOneEngineering label="Next" open="pe-systems" scrollToId="pe-systems-header"/></div>
                     </div>
                  </div>
               </section>
            </div>
            
            <div id="tab-pe-systems" className="enginneeringtab" style={{display: "none"}}>
            <section id="PE Systems sec" >
                  <div className="eng-box box" >
                     <H2 id="pe-systems-header" text="Prime Editing Systems"></H2>
                     <p>Different versions of the original prime editing system have been developed since its initial introduction. Deciding on what system to use for the application in therapeutic human gene editing, especially concerning the correction of F508del, was the goal of this engineering cycle.</p>
                     <p>
                        Since we aim to develop a therapy delivered to the human body, we wanted to obtain high editing efficiency while risking as little off-targets as possible and also reducing the size for improved packability.
                     </p>
                     <InfoBox title="Existing Prime Editing Systems" id="current-pe-systems">
                        <details>
                           <summary>
                              
                           </summary>
                           <div className='row align-items-center'>
                              <div className='col'>
                                 <p>
                                    <b>PE1</b><TabScrollLink tab="tab-pe-systems" num="1" scrollId="desc-1"/>, the first version of the Prime Editor features a Cas9(H840A), a Streptococcus pyogenes Cas9 (SpCas9, hereafter just referred to as Cas9) mutant that only cuts the non-target strand of the DNA template<TabScrollLink tab="tab-pe-systems" num="2" scrollId="desc-2"/>, and a wildtype reverse transcriptase from the Moloney Murine Leukaemia Virus (M-MLV RT) connected by a serine and glycine rich flexible linker.
                                 </p>
                                 <p>
                                    <b>PE2</b><TabScrollLink tab="tab-pe-systems" num="1" scrollId="desc-1"/> improves on this concept by incorporating an improved RT with five mutations improving affinity to the template RNA, enzyme processivity and thermostability (D200N/L603W/T330P/T306K/W313F). This version of the prime editor showed varying improvement of editing efficiency over all tested loci and edits with no apparent downsides. Building on the PE2 system, a smaller version of the M-MLV RT was introduced by Gao et al. (2022)<TabScrollLink tab="tab-pe-systems" num="3" scrollId="desc-3"/>. The RT was truncated by 621 bp through deletion of the RNaseH domain, which originally degrades the RNA template, but is not needed for prime editing. The codon optimized version of this truncated RT prime editor (in literature usually called PE2∆RNaseH) was named <b>PE<sup>CO</sup>-Mini</b> in the paper and will be addressed as such here.
                                 </p>
                              </div>
                              <div className='col-4'>
                              <figure>
                                 <img src="https://static.igem.wiki/teams/5247/engineering-cycle/pe2-open.svg" alt="PE2 Prime Editor"/>  
                                 <figcaption><b>Figure 1: Illustration of PE2 Prime Editor</b> </figcaption>
                              </figure>
                              </div>
                           </div>
                           <div className='row align-items-center'>
                              <div className='col'>
                                 <p>
                                    The <b>PE3</b><TabScrollLink tab="tab-pe-systems" num="1" scrollId="desc-1"/> system, described in the same paper as PE1 and PE2, introduces the use of a second single guide RNA besides the pegRNA which leads to a nick in the strand opposite to the edited strand. This is supposed to improve integration of edits by directing cellular DNA repair systems to use the edited strand as a template for resolving base mismatches. Nicks positioned 3‘ of the edit about 40–90 base pairs from the pegRNA-induced nick were able to further increase editing efficiencies about threefold when compared to PE2, but with a higher range of on-target indels  , meaning random Insertions and/or Deletions that appear after faulty repair of double strand breaks in the DNA. PE3b, where the protospacer for the nicking sgRNA lies within the edited regions, decreased the indel rate greatly compared to PE3.
                                 </p>
                              </div>
                              <div className='col-4'>
                              <img src="https://static.igem.wiki/teams/5247/engineering-cycle/pe3-open.svg" alt="PE3 Prime Editor"/>  
                              </div>
                           </div>
                           <div className='row align-items-center'>
                              <div className='col'>
                                 <p>
                                    <b>PE4</b> and <b>PE5</b><TabScrollLink tab="tab-pe-systems" num="4" scrollId="desc-4"/> expand the PE2 and PE3 systems, respectively, by co-expressing a dominant negative MLH1 protein (MLH1(Δ754–756), hereafter referred to as MLH1dn). The MLH1 protein plays a crucial role in the mismatch repair (MMR) mechanism of the human cell<TabScrollLink tab="tab-pe-systems" num="5" scrollId="desc-5"/> by recruiting other repair proteins and facilitating catalytic function. The mutant still recruits other factors but is impaired in its endonuclease function, disrupting function of the entire repair mechanism. This leads to an average 7.7-fold and 2.0-fold increase in editing efficiency, respectively, compared to PE2 and PE3. This is possibly due to slower repair of mismatches and thus more time for the proteins encoded by LIG1 and FEN1 genes to excise the non-edited 5’ flap and ligate the nick in the edited strand. Additionally, MLH1dn co-expression slightly reduced on-target indels as well as unintended editing outcomes in PE3 systems and did not lead to higher off-target indel rates or overall mutation rates.
                                 </p>
                                 <p>
                                    With <b>PEmax</b><TabScrollLink tab="tab-pe-systems" num="4" scrollId="desc-4"/>, the structure of PE2 is further enhanced by using human codon-optimized RT, a new linker containing a bipartite SV40 nuclear localization sequence (NLS)<TabScrollLink tab="tab-pe-systems" num="6" scrollId="desc-6"/>, an additional C-terminal c-Myc NLS<TabScrollLink tab="tab-pe-systems" num="7" scrollId="desc-7"/> and R221K N394K mutations in SpCas9 previously shown to improve Cas9 nuclease activity<TabScrollLink tab="tab-pe-systems" num="8" scrollId="desc-8"/>. These changes led to moderate improvements in editing efficiency compared to previous editor architectures.
                                 </p>
                              </div>
                              <div className='col-4'>
                              <img src="https://static.igem.wiki/teams/5247/engineering-cycle/pe4-open-new.svg" alt="PE4 Prime Editor"/>
                              <img src="https://static.igem.wiki/teams/5247/engineering-cycle/pe5-open-new.svg" alt="PE5 Prime Editor"/>  
                              </div>
                           </div>
                           <div className='row align-items-center'>
                              <div className='col'>
                                 <p>
                                    <b>PE6</b><TabScrollLink tab="tab-pe-systems" num="9" scrollId="desc-9"/> was made by improving the reverse transcriptase domain of the prime editor using Phage-Assisted Continuous Evolution (PACE). Multiple RT mutants (PE6a-d), derived from RTs of Escherichia coli Ec48 retron, Schizosaccharomyces pombe Tf1 retrotransposon and Moloney Murine Leukaemia Virus,   were identified to increase editing efficiency over and/or were smaller than the M-MLV RT used in previous PE systems. Especially <b>PE6c</b> (evolved Tf1 RT) and <b>PE6d</b> (evolved M-MLV RT) showed significantly higher editing efficiencies than even PEmax depending on the targeted loci, with PE6d showing benefits especially in loci forming more complex secondary structures. Recent advancements in prime editing targeting the CFTR F508Δ mutation showed that PE6c was the most promising for editing in this loci<TabScrollLink tab="tab-pe-systems" num="10" scrollId="desc-10"/>. Improvements of nCas9 on the other hand (PE6e-g) were only marginal and highly site specific. All PE6 systems use nicking gRNAs (PE3) by default, but do not co-express MLH1dn.
                                 </p>
                              </div>
                              <div className='col-4'>
                              <img src="https://static.igem.wiki/teams/5247/engineering-cycle/pe6c-open.svg" alt="PE6c Prime Editor"/> 
                              </div>
                           </div>
                           <div className='row align-items-center'>
                              <div className='col'>
                                 <p>
                                    <b>PE7</b><TabScrollLink tab="tab-pe-systems" num="11" scrollId="desc-11"/> adds an additional RNA binding domain to the Prime Editor. The domain is derived from the La Protein (La(1-194)), an endogenous eukaryotic protein involved RNA metabolism and known for its role in binding polyuridine (polyU) tails at the 3’ ends of nascent transcripts, thus protecting them from exonuclease activity. PE7 showed considerable improvements over PEmax at different loci and different types of edits when used with the PE2 strategy (no nicking gRNAs, no MLH1dn co-expression). Notably, PE7 did perform worse when used with engineered pegRNAs than with regular ones (see pegRNA design).
                                 </p>
                              </div>
                              <div className='col-4'>
                              <img src="https://static.igem.wiki/teams/5247/engineering-cycle/pe7-open.svg" alt="PE7 Prime Editor"/> 
                              </div>
                           </div>
                        </details>
                     </InfoBox> 
                  </div>
                  <div className="box" >
                     <p id="pe1">
                        <PhilipH3 id="pe1head"><span>PE2 and PE<sup>CO</sup>-Mini</span></PhilipH3>
                        <H4 text="Design" id="text"/>
                        <p>
                           For our initial approach, we wanted to start from the beginning and use the PE2 prime editing system. Since our goal of stripping the size of the prime editor was a big factor from the beginning, we did a researched into that direction and found a truncated version of M-MLV RT, PE<sup>CO</sup>-Mini. We then ordered the plasmids for both PE2 and PE<sup>CO</sup>-Mini. Since the PE<sup>CO</sup>-Mini plasmid had a different promotor than pCMV-PE2, we decided to clone the PE<sup>CO</sup>-Mini RT into the pCMV-PE2 vector to allow for direct comparison.
                        </p>
                        <H4 text="Build" id="text"/>
                        <p>
                           We designed primers for the amplification of PE<sup>CO</sup>-Mini RT and cloned it into pCMV-PE2 via double digestion and Gibson assembly.
                        </p>
                        <H4 text="Test" id="text"/>
                        <p>
                           To compare the prime editing performances of M-MLV RT (PE2) and PE<sup>CO</sup>-Mini RT, both were tested using a 2in1 prime editing reporter plasmid system<TabScrollLink tab="tab-pe-systems" num="12" scrollId="desc-12"/> (see <a onClick={() => goToPageWithTabAndScroll({scrollToId: 'Proof of Concept', path: '/engineering', tabId: 'tab-transfection' })}>Proof of Concept</a>) in HEK293 cells. Contrary to the findings of Gao et al., here the PE<sup>CO</sup>-Mini prime editor performed a lot worse than the PE2 prime editor.
                        </p>
                        <H4 text="Learn" id="text"/>
                        <p>
                           Since we knew, that for a successful therapy targeting the F508del mutation a very high prime editing efficiency was of utmost importance, we decided against using PE<sup>CO</sup>-Mini as the basis for our approach and that we have to look for other alternatives.
                        </p>
                     </p>
                  </div>
                  <div className="box" >
                     <p id="pe2">
                        <H3 text="PE6c" id="pe2head"/>
                        <H4 text="Design" id="text"/>
                        <p>
                           During our initial talk with <a onClick={() => goToPagesAndOpenTab('mattijsinv', '/human-practices')}>Mattijs Bulcaen</a>, he recommended a talk of <a onClick={() => goToPagesAndOpenTab('liu', '/human-practices')}>David Liu</a> at an online conference, where he presented unpublished data about his laboratory working on prime editing for F508del correction. We investigated it and through this came across the PE6 generation of prime editors. Seeing that the Liu Laboratory eventually decided on using the PE6c system, we adopted the findings.
                        </p>
                        <H4 text="Build" id="text"/>
                        <p>
                           We got the plasmid carrying the PE6c prime editor. Except for the RT and a few improving mutations in the Cas9 enzyme, it has the same architecture as PE2, which made comparison quite easy.
                        </p>
                        <H4 text="Test" id="text"/>
                        <p>
                           We tested PE6c against PE2 using the same reporter system as mentioned above for PE<sup>CO</sup>-Mini. PE6c, as expected from the literature, proved way more efficient in prime editing.
                        </p>
                        <H4 text="Learn" id="text"/>
                        <p>
                           The data from literature as well as our own experiments confirmed that PE6c architecture is superior to PE2 even without using nicking gRNAs that help suppress mismatch repair. This led us to the decision to use the PE6c reverse transcriptase and parts of the overall architecture for our subsequent tests.
                        </p>
                     </p>
                  </div>
                  <div className="box" >
                     <p id="pe3">
                        <H3 text="PreCyse Casette" id="pe3head"/>
                        <H4 text="Design" id="text"/>
                        <p>
                           In the later stages of our project, the Liu laboratory published their own findings regarding CFTR F508del targeting with prime editing<TabScrollLink tab="tab-pe-systems" num="10" scrollId="desc-10"/>. The data showed that the editing efficiency of PE2 based systems, even when using PE6c reverse transcriptase, might not be sufficient for application in a therapy. Also, the plasmids of current prime editors did not include restriction sites that would have allowed replacing components like the nickase to test alternatives. This is why, in a cherry-picking manner, we combined the PE6c architecture prime editor with the most promising aspects of other prime editors, creating the PreCyse cassette.
                        </p>
                        <p>
                           Our decision on what components of existing prime editors we wanted to use was mainly driven by two factors: efficiency and precision. In prime editing, these two are often opposing forces, which means advancements improving efficiency often also increase the risk of off-targets mutations and on-target undesired editing. For this reason, we decided against using nicking gRNAs. Although they have been proven to reliably improve editing efficiency, they increase the risk and possible scope of off-target cleavage and mutations. Additionally, if <b>PE3b</b> is not applicable, there is a chance for double strand breaks to occur, which diminishes the safety advantage of prime editing over other common CRISPR-based methods. Co-expression of MLH1dn can improve editing efficiency in the same way as nicking gRNAs do, by helping to evade of the cellular mismatch repair mechanisms. The use of MLH1dn is especially impactful, when nicking gRNAs are not used, which is perfect in our case. Recently, the La poly(U)-binding motif has been shown to enhance prime editing efficiency, presumably through protection of the 3’ poly(U) tail of the pegRNA from RNases. The motif is also comparatively small, which aligns with the overall goal to create a compact prime editing tool. This is why PreCyse Casettes have been designed to include the La RNA binding motif fusion and the dominant negative MLH1 protein.
                        </p>
                        <H4 text="Build" id="text"/>
                        <p>
                           The PreCyse cassette comes in three versions: PreCyseA, the most basic version, comprises of a T7 promoter and an open reading frame, which includes NLS and one typeIIS restriction enzyme cloning site for a nickase and a reverse transcriptase each. For possible future additions like e. g. selection markers, a BamHI restriction site at the end of the coding sequence allows for easy in-frame Gibson cloning. Building on this basis, PreCyseB expands PreCyseA by the La Poly(U)-binding motif. PreCyseC additionally introduces the co-expressed MLH1dn. The cassettes were ordered in three individual parts to be put together with a pCMV-PE6c backbone via Gibson Cloning in different configurations to create the three variants. In the plasmid the cassette is expressed under a CMV promoter and followed by a polyadenylation signal. The PreCyse Casettes themselves can be used as a BioBrick RFC[10] standard compatible composite part can thus be freely combined with other parts. The nickase and RT slots can be used for inserting any basic or composite part compatible with the Type IIS RCF[1000] standard for fusion proteins. The PreCyse Casette is meant to be a contribution to the iGEM community and a base for other teams to join us and researchers around the world to innovate in the exciting field of prime editing.
                        </p>
                        <div className="casettecontainer">
                           <div className="casettebox">
                              <H5 text="PreCyseA" id="PCA"/>
                              <img src="https://static.igem.wiki/teams/5247/engineering-cycle/precysea-casette.svg" alt="image 1" />
                           </div>
                           <div className="casettebox">
                              <H5 text="PreCyseB" id="PCB"/>
                              <img src="https://static.igem.wiki/teams/5247/engineering-cycle/precyseb-casette.svg" alt="image 2" />
                           </div>
                           <div className="casettebox">
                              <H5 text="PreCyseC" id="PCC"/>
                              <img src="https://static.igem.wiki/teams/5247/engineering-cycle/precysec-casette.svg" alt="image 3" />
                           </div>
                        </div>
                        {/* <div className="row align-items-center">
                           < div className='col align-items-center'>
                              <H5 text="PreCyseA" id="PreCyseA"/>
                              <img src="https://static.igem.wiki/teams/5247/engineering-cycle/precysea-casette.svg" alt="PreCyseA modular PE casette" style={{height: "80pt", width: "auto"}}/>  
                           </div>
                           <div className='col align-items-center'>
                              <H5 text="PreCyseB" id="PreCyseB"/>
                              <img src="https://static.igem.wiki/teams/5247/engineering-cycle/precyseb-casette.svg" alt="PreCyseB modular PE casetter" style={{height: "80pt", width: "auto"}}/>  
                           </div>
                        </div>
                        <div className='row align-items-center'>
                           <H5 text="PreCyseC" id="PreCyseC"/>
                           <img src="https://static.igem.wiki/teams/5247/engineering-cycle/precysec-casette.svg" alt="PreCyseC modular PE casette" style={{height: "80pt", width: "auto"}}/>  
                        </div> */}
                     </p>
                  </div>
                  <Section title="References" id="references">
                     <EngPEsystems/>
                  </Section>
                  <br/>
                  <div className="row ">
                     <div className="col">
                     <div className="left"><ButtonOneEngineering label="Previous" open="transfection" scrollToId="transfection-header"/></div>
                     </div>
                     <div className="col button-left">
                        <div className="right"><ButtonOneEngineering label="Next" open="pegrna" scrollToId="pegrna-header"/></div>
                     </div>
                  </div>
               </section>
            </div>
            
            <div className="enginneeringtab" id="tab-pegrna" style={{display: "none"}}>
            <section id="pegRNA sec" >
                  <div className="eng-box box" >
                     <H2 id="pegrna-header" text="pegRNA"></H2>
                     <p>The <a onClick={() => goToPagesAndOpenTab('pegrna', '/engineering')}> pegRNA </a> is of paramount importance for function and efficiency of prime editors, as it plays a role in every step of the prime editing mechanism. It is therefore equally important to optimize the pegRNA than it is to have an optimized prime editor. Hence this engineering cycle explains our process of optimizing the pegRNAs for our genomic target, CFTR F508del. Given that different areas of the pegRNA have different functionalities, the following iteration cycles will demonstrate how improvements and optimizations have been made to these various functional domains in relation to the CFTR context. This was achieved through research, the correspondence with of experts and experiments.</p>
                  </div>
                  <div className="box" >
                     <p id="peg1">
                        <H3 text="Initial pegRNA Design and Silent Edits" id="peg1head"/>
                        <p>
                           The first iteration of our engineering cycle, we designed our first set of pegRNAs targeting the <a onClick={() => goToPageWithTabAndScroll ({scrollToId: 'reporter-header', path: '/engineering', tabId: 'reporter' })}>modified pPEAR_CFTR reporter</a>. We also focused on the incorporation of silent edits.
                        </p>
                        <H4 text="Design" id="design-head"/>
                        <p>
                           Following an interview with <a onClick={() => goToPagesAndOpenTab('JPpegRNA', '/human-practices')}>Jan-Phillipp Gerhard</a>, we came across the concept of silent edits. Silent edits refer to single-base alterations of the nucleotide sequence that do not change the encoded amino acid. Jan-Phillipp pointed out that introducing silent edits in addition to the intended edit offers two major advantages.
                        </p>
                        <p>
                           Firstly, silent edits can increase the likelihood of flap incorporation during the prime editing process, especially in the context of MMR (Mismatch Repair) in the cell. Without silent edits, the cell is more likely to detect the mismatches that only occur at the desired mutation site, leading to a higher chance of the wild-type flap being reinserted. By introducing silent edits, multiple mismatches are present which this increases the probability of the synthesized flap being incorporated.
                        </p>
                        <p>
                           Secondly, silent edits can prevent re-binding of the prime editing complex to the target region after successful editing. This is be achieved by introducing silent edits to the regions making up PAM sequence and/or protospacer. PAM or protospacer disruption make the editing process more secure. This is because it reduces the likelihood of editing the target region repeatedly, which would increase the probability of on-target undesired editing outcomes. He suggested that swapping cytosine or guanine bases for these silent edits can be particularly effective in improving prime editing efficiency.
                        </p>
                        <H4 text="Build" id="build-head"/>
                        <p>
                           We designed several pegRNAs, both with and without silent edits. To assist with this, we used the pegFinder software<TabScrollLink tab="tab-pegrna" num="1" scrollId="desc-1"/>, which generated possible variations of pegRNAs based on the sequence of the reporter plasmid. We selected the optimal pegRNA as suggested by the software, and then tested it in two forms: one unmodified and one with silent edits. For the unmodified variant, we included a single silent edit that introduced a PAM disrupt in terms of our biosafety measures. For the modified variant, we introduced three silent edits in total, adding two more to the initial edit. 
                        </p>
                        <p>
                           Once we had designed these variants, we ordered them in their individual components and cloned them into a pU6-peg-GG-acceptor backbone using Golden Gate cloning according to the protocol from Anzalone et al. 2019<TabScrollLink tab="tab-pegrna" num="2" scrollId="desc-2"/>. We then screened the assembled pegRNAs to ensure that the individual components had the correct orientation and then cloned them into the pU6-GG-pegRNA-acceptor plasmid so that they were ready to be tested.
                        </p>
                        <H4 text="Test" id="test-head"/>
                        <p>
                           These two variants were then tested against each other using our <a onClick={() => goToPageWithTabAndScroll ({scrollToId: 'rep3', path: '/engineering', tabId: 'reporter' })}>pPEAR_CFTR reporter plasmid system</a> and a <a onClick={() => goToPageWithTabAndScroll ({scrollToId: 'scroll target id', path: '/page', tabId: 'tabid' })}>PE2 prime editor</a>. The test of the pegRNAs was conducted by co-transfecting the reporter system, the pegRNA plasmids and the PE2 plasmids into HEK293 cells.
                        </p>
                        <H4 text="Learn" id="learn-head"/>
                        <p>
                           The results showed that the editing efficiency of the variant without silent edits was superior to the variant with silent edits, which considering our input was not expected. But as we have learned in the interview with Jan-Phillipp Gerhard, these silent edits are especially effective in avoiding mismatch repair (MMR) inside human cells. Form <a onClick={() => goToPagesAndOpenTab('mattijsinv', '/human-practices')}> Mattijs Bulcaen </a> we learned, that HEK293 cells are deficient in this very mechanism. From this we deduced that we had to test the silent edits in lung ephital cells to get a valid result.
                        </p>
                     </p>
                  </div>
                  <div className="box" >
                     <p id="peg2">
                        <H3 text="Screening of pegRNA variants" id="peg2head"/>
                        <p>
                           In this second iteration, we focused on further optimizing our pegRNA by incorporating a stem loop and experimenting with different lengths of the PBS (Primer Binding Site) and RTT (Reverse Transcriptase Template). These modifications were inspired by a combination of literature research and expert interviews. After evaluating the performance of the pegRNAs using flow cytometry, we selected the three most effective candidates.
                        </p>
                        <H4 text="Design" id="design-head"/>
                        <p>
                           Based on literature reviews and our interview with <a onClick={() => goToPagesAndOpenTab('mattijsinv', '/human-practices')}> Mattijs Bulcaen </a>, we decided to modify our pegRNA by adding a stem loop to enhance its stability. Specifically, Mattijs recommended using the tevopreQ1 stem loop, a small structural motif that increases the pegRNA's resistance to RNases. This stem loop was added to the 3' end of the pegRNA, positioned after the PBS.
                        </p>
                        <p>
                           Additionally, during a webinar with B. Sc. Jordan Doman<TabScrollLink tab="tab-pegrna" num="3" scrollId="desc-3"/>, we learned that it is important to test various lengths of PBS and RTT, as there is no universally optimal length for all applications. Instead, the ideal lengths are application specific. Following this advice, we designed six different pegRNA variants with combinations of two different PBS lengths (16 and 17 nucleotides) and three different RTT lengths (27, 30, and 33 nucleotides).
                        </p>
                        <p>
                           We chose the PBS lengths of 16 and 17 nucleotides based on an earlier recommendation from Jan-Phillipp Gerhard, who emphasised that the annealing temperature of the PBS should match the environmental conditions relevant to the intended application. In our case, since we are exploring a potential therapeutic approach, it is important that the annealing temperature of the PBS is close to the body temperature of 37 °C, which is the case for these lengths. The RTT lengths were selected based on suggestions from the pegFinder software. As with our previous insights, we designed all six variants both with and without silent edits for a wider comparison of the silent edits, making it 12 variants in total.
                        </p>
                        <H4 text="Build" id="build-head"/>
                        <p>
                           Once we had designed these variants, we ordered them in their individual components and cloned them together using Golden Gate cloning. This was a much more resource-efficient and sustainable option, as only the PBS and/or RTT lengths differed. Thus, there was a constant pegRNA part, consisting of spacer and scaffold, and a variable part, consisting of PBS, RTT and stem loop. We then cloned these variants into the pU6-GG-pegRNA-acceptor plasmid and confirmed the correct orientation and successful cloning of all constructs through screening.
                        </p>
                        <H4 text="Test" id="test-head"/>
                        <p>
                        We tested these twelve pegRNA variants against each other and the two previous variants without the trevopreQ1 stem loop, again within the PE2 system, using our reporter system, to assess their editing efficiency. The experimental setup was similar to the cycle before.
                        </p>
                        <H4 text="Learn" id="learn-head"/>
                        <p>
                           From this round of testing, we found out that our engineered pegRNA variants pegRNA04, 05, 07 and 08 exhibited the highest levels of efficiency and stability, while the pegRNA12 showed the lowest level of editing efficiency. Therefore, we reasoned to go with these four pegRNA variants as well as pegRNA12 as a negative example for follow-up experiments.
                        </p>
                     </p>
                  </div>
                  <div className="box" >
                     <p id="peg3">
                        <H3 text="Application lung epithelial cell lines" id="peg3head"/>
                        <p>
                           HEK cells are an easy to handle and easy to edit cell model. However, they are not particularly similar to the cells that would actually be useful targets for a gene therapy. In our context, two key differences are especially grave: HEK cells, as mentioned above, are impaired in mismatch repair, making them easier to edit, and they do not naturally express CFTR.
                        </p>
                        <H4 text="Design" id="design-head"/>
                        <p>
                           In this third iteration, we wanted to investigatee the applicability of a pegRNA optimized in a model closer to therapeutic application. In our case we used in <a onClick={() => goToPageAndScroll ('Cell Culture2H', '/materials-methods')}>CFBE41o- epithelial cells lines</a> homozygous for the CFTR F508del mutation.
                        </p>
                        <H4 text="Build" id="build-head"/>
                        <p>
                           For this test, we used one of the pegRNAs (pegRNA04) that showed the highest efficiencies in previous optimization steps. Since we expected only low editing efficiencies compared to HEK cells for reasons mentioned above, we used the <a onClick={() => goToPageWithTabAndScroll ({scrollToId: 'pe2', path: '/engineering', tabId: 'pe-systems' })}>PE6c prime editor</a>. It had proven to be most effective in HEK cells in our <a onClick={() => goToPagesAndOpenTab('pe-systems', '/engineering')}> pe systems engineering cycle </a> and should ensure detectability of possible editing.
                        </p>
                        <H4 text="Test" id="test-head"/>
                        <p>
                           We co-transfected the CFBE41o- with our modified <a onClick={() => goToPagesAndOpenTab('reporter', '/engineering')}> reporter system </a>, the plasmid expressing pegRNA04 as well as pCMV-PE6c. As a result, we observed fluorescence, indicating successful editing of the reporter plasmid. The negative controls transfected with only one of the plasmids each showed no fluorescence, routing out other factors.
                        </p>
                        <H4 text="Learn" id="learn-head"/>
                        <p>
                           Thanks to this experiment we knew, that our pegRNAs work not only in HEK, but also in epithelial cells that express CFTR F508del.
                        </p>
                     </p>
                  </div>
                  <div className="box" >
                     <p id="peg4">
                        <H3 text="Application to genomic CFTR targeting" id="peg4head"/>
                        <p>
                           In this fourth iteration, we aimed to transfer our findings in optimizing the pegRNAs, generated in previous iterations, to the genomic CFTR context. To this end we modified our pegRNAs to be used in the CFTR gene editing process.
                        </p>
                        <H4 text="Design" id="design-head"/>
                        <p>
                           Using the pegFinder software and our acquired expertise in creating pegRNAs, we designed the new variants specifically tailored to the genomic CFTR region. These pegRNAs included the same combinations of PBS and RTT lengths as the ones we created for our reporter plasmid. Notably, scaffold, spacer, PBS and a part of the RTT did not have to be changed from the reporter targeting to genome targeting pegRNAs. Of the created pegRNAs, we wanted to focus on testing the most effective four variants found in the previous cycles and also a variant designated comparatively ineffective to test for consistency of our reporter system.
                        </p>
                        <H4 text="Build" id="build-head"/>
                        <p>
                           The newly designed pegRNAs were ordered as separate components, identical to the process used for the pegRNAs targeting the reporter system. Each RNA had both a constant and variable region, which we assembled using Golden Gate cloning. Afterwards we confirmed the correctness and completeness of the cloning into the pU6-peg-GG-acceptor plasmid through colony PCR screening. Unfortunately to this point, we were not able to produce positive clones.
                        </p>
                        <H4 text="Test" id="test-head"/>
                        <p>
                           The next step is to test the correction of CFTR F508del using these pegRNAs in the CFBE41o- epithelial cells. Additionally, we also want to test the pegRNAs in primary cells derived from friend of the team and cystic fibrosis patient <a onClick={() => goToPagesAndOpenTab('maxfirst', '/human-practices')}> Max </a>, testing whether our approaches are applicable not only in model systems, but also work in patient cells. To validate the editing efficiency of our designed pegRNAs were going to co-transfect a plasmid carrying an eYFP variant which is sensitive to chloride and iodide ion concentrations<TabScrollLink tab="tab-pegrna" num="4" scrollId="desc-4"/><TabScrollLink tab="tab-pegrna" num="5" scrollId="desc-5"/>. The intensity of the fluorescence correlates with these ion concentrations, which in turn reflects the functionality of the CFTR channel. This enables us to evaluate the editing efficiency of the different pegRNA variants on a phenotypic level. After 72 hours, we are going to perform a final analysis using flow cytometry to quantify the results and determine the editing efficiency of each pegRNA. Secondly, we wanted to detect the editing on a genomic level by facilitating a qPCR with a primer specific only to the corrected F508del locus.
                        </p>
                        <H4 text="Learn" id="learn-head"/>
                        <p>
                           With this experiment we hope to achieve two things: Firstly, we want to examine whether optimizations of pegRNAs designed for our reporter system actually transfer to the genomic CFTR targeting. Secondly and most importantly, we want to find out whether we actually created an effective gene editing strategy for the genomic context of CFTR, thereby providing a foundation for a future gene therapy with high efficiency and precision when used with the right prime editor.
                        </p>
                     </p>
                  </div>
                  <div className="box" >
                     <p id="peg5">
                        <H3 text="Outlook" id="peg5head"/>
                        <p>
                           In this final iteration, we focus on the outlook for future modifications and optimizations of our pegRNA design. These concepts are meant to further improve both the stability and editing efficiency through additional research and the implementation of new design strategies.
                        </p>
                        <H4 text="Design" id="design-head"/>
                        <p>
                           As we continued to refine our approach, further literature research was conducted, and new design ideas considered. The overarching goal remained to enhance both the stability and editing efficiency of the pegRNAs. One concept we are already exploring involves the incorporation of 3’ and 5’ UTRs (Untranslated Regions)<TabScrollLink tab="tab-pegrna" num="6" scrollId="desc-6"/>. These elements, typically found in mRNA, could be added to the pegRNA to increase its stability.
                        </p>  
                        <p>   
                           Another promising idea is the use of circular RNA (circRNA)<TabScrollLink tab="tab-pegrna" num="7" scrollId="desc-7"/>, which could provide additional stability by maintaining the closed-loop structure of the pegRNA. This would prevent degradation and increase the longevity of the pegRNA in the cell. 
                        </p>
                        <p>
                           Additionally, further nucleotide modifications could be explored, such as experimenting with alternative silent edits to see if this leads to improved editing efficiency. We also nucleotide substitutions in the scaffold region to enhance RNA-binding affinity to the protein complex could be of use.
                        </p>
                        <H4 text="Build" id="build-head"/>
                        <p>
                           To implement these new design features, the individual components, such as UTRs, would need to be cloned into the existing pegRNAs. If we pursue alternative silent edits, the pegRNA sequences would need to be redesigned, ordered, and re-cloned. The circular RNA would also require a new assembly method to achieve the desired structure. However, the fundamental workflow would remain consistent with the processes used in previous iterations.
                        </p>
                        <H4 text="Test" id="test-head"/>
                        <p>
                           To maintain consistency and comparability, the same testing protocols used for the previous pegRNA screening would be applied. This includes co-transfection in the appropriate cell lines, fluorescence-based readouts for editing efficiency, and flow cytometry analysis. By keeping the experimental conditions the same, we can ensure that the effects of the new modifications can be accurately assessed and compared to previous results.
                        </p>
                        <H4 text="Learn" id="learn-head"/>
                        <p>
                           From these tests, we would aim to derive new insights not only specific to our particular context but also for pegRNA design as a whole. These future modifications could also yield valuable information on how to further improve the overall efficiency and stability of pegRNAs, contributing to the broader field of gene editing.
                        </p>
                     </p>
                  </div>
                  <Section title="References" id="references">
                     <EngPegsources/>
                  </Section>
                  <br/>
                  <div className="row ">
                     <div className="col">
                     <div className="left"><ButtonOneEngineering label="Previous" open="pe-systems" scrollToId="pe-systems-header"/></div>
                     </div>
                     <div className="col button-left">
                        <div className="right"><ButtonOneEngineering label="Next" open="nickase" scrollToId="nickase-header"/></div>
                     </div>
                  </div>
               </section>
            </div>
            <div className="enginneeringtab" id="tab-nickase" style={{display: "none"}}>
            <section id="Nickase sec" >
                  <div className="eng-box box" >
                     <H2 id="nickase-header" text="Alternative Nickases"></H2>
                     <p>The Cas9 nickase is the key component of most current prime editing system. It is needed for localizing the genomic target and cutting a single DNA strand. The complex's size and RNA stability issues limit its efficiency. To overcome these challenges, we explored smaller endonucleases like CasX and Fanzor, which not only reduce the size of the complex but also offer structural advantages such as a reversed guide RNA architecture. We theorize that this unique configuration protects the RNA from degradation and improves editing precision by reducing the risk of unwanted genomic alterations by scaffold readthrough, making CasX and SpuFz1 promising alternatives to Cas9-based systems for prime editing.</p>
                  </div>
                  <div className="box" >
                     <p id="nic1">
                        <H3 text="SpuFz1 Zink Finger Mutation " id="nic1head"/>
                        <H4 text="Design" id="text"/>
                        <p>
                           In our quest to identify smaller endonucleases suitable for creating nickases, we focused on a newly characterized family of eukaryotic endonucleases known as Fanzor proteins first described in June 2023<TabScrollLink tab="tab-nickase" num="1" scrollId="desc-1"/>, with SpuFz1 (Fig. 1) being a standout candidate due to its smaller size compared to Cas9 (SpuFz1 consists of 638 amino acids<TabScrollLink tab="tab-nickase" num="1" scrollId="desc-1"/>, whereas Cas9 has a size of 1368 amino acids<TabScrollLink tab="tab-nickase" num="2" scrollId="desc-2"/>). We selected SpuFz1 not only because of its smaller size, but also due to structural advantages, such as the reversed positioning of the spacer, which provides better protection from RNase degradation and improves editing precision.
                        </p>
                        <p>
                           The Cas9 endonuclease contains two active domains, each responsible for cutting one of the two DNA strands. Cas9 uses the RuvC and HNH domains, with each domain making a cut on a different strand of the target DNA<TabScrollLink tab="tab-nickase" num="3" scrollId="desc-3"/>. To create a nickase from Cas9, scientists deactivate one of these active domains, typically the HNH domain, so that the enzyme only cuts one strand instead of both, producing a single-strand break rather than a double-strand break<TabScrollLink tab="tab-nickase" num="4" scrollId="desc-4"/>.
                        </p>
                        <p>
                           Based on the function of this prototypical Cas9 nickase, we assumed that SpuFz1 would operate similarly, with two active centers—RuvC and TNB—each cutting one DNA strand. Following this logic, we hypothesized that by deactivating the TNB domain, which contains a zinc finger motif (Fig. 2) crucial for DNA coordination, we could convert SpuFz1 into a nickase. To test this, we aimed to replace the cysteine residues involved in zinc ion coordination within the TNB domain with alanine, thereby impairing its DNA-binding ability and producing a SpuFz1 nickase that cuts only one strand. At that time, we believed both domains in SpuFz1 were directly responsible for DNA cleavage, and our strategy was based on this assumption.
                        </p>
                        <figure>
                           <div className="row align-items-center">
                              <div className="col">
                                 <img src="https://static.igem.wiki/teams/5247/engineering-cycle/spufz-wt-3d-model.webp"/>
                              </div>
                              <div className="col">
                                 <img src="https://static.igem.wiki/teams/5247/engineering-cycle/spufz-wt-3d-model-zinc-finger.webp"/>
                              </div>
                           </div>
                           <figcaption>
                           <div className="row align-items-center">
                                 <div className="col">
                                    <b>Figure 1:</b> Schematic illustration of SpuFz1 (PDB code: 8GKH) visualized in ChimeraX 
                                 </div>
                                 <div className="col">
                                    <b>Figure 2:</b>  Close up of the zinc finger motif of SpuFz1 (PDB code: 8GKH) visualized in ChimeraX - in the middle of the image the zinc ion of the motif can be seen, which is coordinated by 4 surrounding cysteine residues
                                 </div>
                           </div>
                           </figcaption>
                        </figure>
                        <H4 text="Build" id="text"/>
                        <p>
                           Using the protein visualization software ChimeraX, we carefully examined the structure of SpuFz1 to identify the key cysteine residues responsible for coordinating the zinc ion. With this insight, we designed our nickase candidates by modifying the wild-type sequence, specifically substituting these cysteines with alanine, to disrupt the zinc ion coordination and potentially alter the protein's function.
                        </p>
                        <H4 text="Test" id="text"/>
                        <p>
                           First, we discussed our approach with <a onClick={() => goToPagesAndOpenTab('hammerkai', '/human-practices')}> Kai Schülke </a>, a PhD student from the Hammer Group at Bielefeld University, which specializes in enzyme engineering. He confirmed that our plan to focus on specific mutation candidates was appropriate given the constraints of our project. He emphasized that we lacked the time and resources to conduct large-scale, quantitative studies on a wide range of mutations. Instead, he supported our decision to target specific candidates that could be thoroughly tested within the scope of our project.
                        </p>
                        <p>
                           Additionally, we carefully considered the potential effectiveness of our modified SpuFz1 nickase in a Prime Editing scenario, specifically targeting the F508del mutation in cystic fibrosis. During this detailed analysis, we identified a critical challenge: the TAM sequence required for SpuFz1 binding was located too far from the target mutation site. This distance could limit the efficiency of the Prime Editor, raising concerns about its overall effectiveness for this particular mutation.
                        </p>
                        <InfoBox title="TAM sequences" id="current-pe-systems">
                           <details>
                              <summary>
                                 A TAM sequence is the equivalent to a PAM sequence for OMEGA systems.
                              </summary>
                              <p>
                                 A <b>TAM sequence</b> (Targeted Activity Modification sequence) is a short DNA sequence, typically only a few bases long, that provides a binding site for the nickase within the Prime Editing complex. This sequence is crucial because it allows the nickase to bind to the DNA and make a precise single-strand cut. For the Prime Editing complex to correct a mutation at a specific location guided by the pegRNA, a TAM sequence must be located near that target site. While the pegRNA directs the editing machinery to the region where the correction will occur, the TAM sequence enables the nickase to physically interact with the DNA and initiate the cut. Therefore, both the pegRNA and the TAM sequence are essential for efficient and accurate editing: the pegRNA specifies the site of the correction, and the TAM sequence facilitates the nickase's binding and action. For instance, SpuFz1 recognizes the TAM sequence <b>5'-CATA-3'</b>, and CasX binds to <b>5'-TTCN-3'</b>. 
                              </p>
                           </details>
                        </InfoBox> 
                        <H4 text="Learn" id="text"/>
                        <p>
                        Through this iteration, we learned that targeted mutagenesis is a promising approach for generating our mutant nickases. We also recognized the importance of carefully selecting the appropriate PAM or TAM sequences for our chosen endonucleases. Specifically, we realized that the TAM sequence for SpuFz1 might be too far from our target mutation, prompting us to explore other endonucleases within the Fanzor family that could serve as better candidates for nickase development. Additionally, this process highlighted the critical role of expert consultation in refining our strategies and ensuring the feasibility of our approach.
                        </p>
                     </p>

                  <div className="box" >
                     <p id="nic2">
                        <H3 text="Fusion Protein from GtFz1 & SpuFz1" id="nic2head"/>
                        <H4 text="Design" id="design-head"/>
                        <p>
                           In our ongoing exploration of Fanzor proteins, we identified another potential candidate, GtFz1, which had a suitable TAM sequence for our target application of correcting the F508del mutation in cystic fibrosis. However, GtFz1 showed low cutting efficiency in the tests reported in the literature<TabScrollLink tab="tab-nickase" num="1" scrollId="desc-1"/>. To address this, we devised a strategy to combine the favorable TAM-binding properties of GtFz1 with the higher cutting efficiency of SpuFz1. Specifically, we planned to engineer a fusion protein by replacing the TAM-binding domain of SpuFz1 with that of GtFz1. This approach aims to create an endonuclease that retains the strong TAM-binding ability of GtFz1 while utilizing the robust cutting efficiency of SpuFz1, optimizing it for our Prime Editing application.
                        </p> 
                        <p>  
                           Given that we were swapping entire domains rather than just single amino acids, we realized that the fusion protein might not retain the ideal TAM-binding efficiency or cutting efficiency of the original proteins. Our strategy was to create a fusion protein that could bind to the TAM site and perform DNA cutting to a certain extent, albeit weakly. We planned to use directed evolution techniques, such as Phage Assisted Continuous Evolution (PACE), to enhance these functionalities over time. This approach relies on having a starting point with some degree of the desired activity, which can then be incrementally improved through evolution.
                        </p>
                        <H4 text="Build" id="build-head"/>
                        <p>
                           The build phase involved designing this fusion protein by integrating the TAM-binding region from GtFz1 into the SpuFz1 protein structure. We engineered the sequence to include this hybrid configuration, intending to test its functionality as a nickase after introducing the zinc finger mutation, which we had hypothesized would inactivate one of the DNA-cutting domains.
                        </p>
                        <H4 text="Test" id="test-head"/>
                        <p>
                           To validate our approach, we conducted two key interviews. First, we consulted with <a onClick={() => goToPagesAndOpenTab('hammer', '/human-practices')}> Prof. Dr. Hammer </a> from Bielefeld University, who highlighted the possibility that the zinc finger domain might be structurally significant and cautioned that mutating it could destabilize the protein. He recommended that we explore whether there were any known enzymes with similar mechanisms where analogous mutations had successfully converted endonucleases into nickases. This approach, he suggested, might offer a more reliable pathway.
                        </p>
                        <p>
                           Next, we spoke with <a onClick={() => goToPagesAndOpenTab('svenja', '/human-practices')}> Svenja Finke </a>, a Postdoctoral Fellow at the Harvard Institute and an expert in directed enzyme evolution, including PACE. We reached out to her specifically because we anticipated that our fusion protein might require optimization to achieve strong TAM-binding and cutting efficiency. Svenja informed us that while PACE could theoretically optimize our fusion protein, the process was too complex and time-consuming for the scope of our project. As a result, we decided to reconsider this method and look for simpler, more feasible alternatives.
                        </p>
                        <H4 text="Learn" id="learn-head"/>
                        <p>
                           From this iteration, we learned several important lessons. First, we decided to abandon the fusion protein approach. Feedback from Svenja’s interview highlighted that this strategy was too complex, time-consuming, and involved significant uncertainty regarding its effectiveness. Given the long testing times and the inherent risks, we concluded that this approach was not viable within our project’s constraints. Initially, we considered moving away from SpuFz1 due to the TAM sequence being too far from the ΔF508 mutation. However, with ongoing improvements in reverse transcriptases within Prime Editing systems, which allow for greater distances between the mutation site and the TAM sequence, we refocused our efforts on SpuFz1, considering it a viable candidate for further development.
                        </p>
                        <p>
                           Secondly, we realized the importance of verifying whether the zinc finger mutation we proposed is structurally feasible and whether it might compromise protein stability. This insight further emphasized the need to carefully assess our design choices before proceeding to extensive testing.
                        </p>
                     </p>
                  </div>
                  <div className="box" >
                     <p id="Modeling of Mutant Structural Integrity">
                        <H3 text="nic3" id="nic3head"/>
                        <H4 text="Design" id="design-head"/>
                        <p>
                           In the previous iteration, we consulted <a onClick={() => goToPagesAndOpenTab('hammer', '/human-practices')}> Prof. Dr. Hammer </a>, who suggested that the zinc finger domain in the SpuFz1 protein might play a critical structural role. Based on this feedback, the goal of this iteration was to investigate whether mutating the zinc finger would destabilize the protein and compromise its function. Specifically, we aimed to determine if altering this domain would still be a viable strategy for generating a SpuFz1-based nickase without losing structural integrity.
                        </p>
                        <H4 text="Build" id="build-head"/>
                        <p>
                           Before, we identified the specific amino acids responsible for coordinating the zinc ion within the zinc finger domain. Using the software Geneious, we proceeded to design DNA sequences by substituting these key amino acids with ones that would impair their ability to coordinate the zinc ion. These designed sequences corresponded to our potential mutation candidates, which we prepared for further structural analysis.
                        </p>
                        <H4 text="Test" id="test-head"/>
                        <p>
                           We used AlphaFold to model the 3D structures of our zinc finger mutation candidates. After generating these models, we used ChimeraX to perform a structural overlay comparison between the native SpuFz1 protein and the mutated versions (Fig. 3). This comparison revealed significant differences, particularly in the TNB domain, indicating that the zinc finger plays a crucial structural role (Fig. 4).
                        </p>
                        <figure>
                           <div className="row align-items-center">
                              <div className="col">
                                 <img src="https://static.igem.wiki/teams/5247/engineering-cycle/spufz-wt-vs-zf-nikase.webp"/>
                              </div>
                              <div className="col">
                                 <img src="https://static.igem.wiki/teams/5247/engineering-cycle/spufz-wt-vs-zf-nikase-zinc-finger.webp"/>
                              </div>
                           </div>
                           <figcaption>
                           <div className="row align-items-center">
                                 <div className="col">
                                    <b>Figure 3:</b> Structural overlay of wildtype SpuFz1 (color: Lilac) (PDB code: 8GKH) and modeled zinc-finger mutation candidate (color: orange) visualized in ChimeraX – the yellow circle shows the location of the zinc-finger. A structural deviation of both proteins locally is evident.
                                 </div>
                                 <div className="col">
                                    <b>Figure 4:</b> Close-up of the zinc finger motif of the structural overlay - the zinc finger appears to be structurally significant: there are strong structural differences locally
                                 </div>
                           </div>
                           </figcaption>
                        </figure>
                        <H4 text="Learn" id="learn-head"/>
                        <p>
                        From this analysis, we concluded that the zinc finger mutation is not a suitable candidate for generating a nickase, as altering this domain would likely compromise the structural integrity of SpuFz1. Prof. Hammer suggested that instead of focusing on SpuFz1, we explore other endonucleases with similar mechanisms. His recommendation was to identify endonucleases that are structurally comparable to SpuFz1 and analyze the strategies used to convert these into nickases. We would then apply these same strategies to our selected endonucleases, adapting them for our purposes.
                        </p>
                     </p>
                  </div>
                  <div className="box" >
                     <p id="nic4">
                        <H3 text="nCas12 analog Mutations" id="nic4head"/>
                        <H4 text="Design" id="design-head"/>
                        <p>
                           After concluding that the zinc finger mutation approach was not suitable for converting SpuFz1 into a nickase, we revisited our understanding of its cutting mechanism. Initially, we believed that SpuFz1, similar to Cas9, contained two active centers that each cut one of the DNA strands, and that by deactivating one of these centers, we could generate a nickase that only cuts one strand. However, through further research, we discovered that this assumption was incorrect. SpuFz1 actually functions with a different cutting mechanism: the RuvC domain is responsible for cutting the non-target strand, while the TNB domain does not directly cut the DNA. Instead, it assists the process by guiding the target strand into the RuvC domain for sequential cleavage<TabScrollLink tab="tab-nickase" num="5" scrollId="desc-5"/>. This discovery shifted our focus from simply deactivating an active site to better understanding how the sequential cleavage works in order to inform future mutation strategies.
                        </p>
                        <p>
                           In addition to these insights, we noticed a significant phylogenetic relationship between Fanzor endonucleases, like SpuFz1, and Cas12 endonucleases<TabScrollLink tab="tab-nickase" num="1" scrollId="desc-1"/>. This connection was crucial, as Cas12 proteins have a similar cutting mechanism to Fanzor proteins, utilizing a single active site for cleavage while coordinating both DNA strands. More importantly, we identified a precedent in the literature where a Cas12a endonuclease was successfully converted into a nickase by substituting a single amino acid in the TNB domain<TabScrollLink tab="tab-nickase" num="6" scrollId="desc-6"/> (Fig. 5 and 6). This provided us with a clear model strategy to follow, as this targeted mutation allowed the endonuclease to selectively cut only one DNA strand, effectively converting it into a nickase.
                        </p>
                        <figure>
                           <div className="row align-items-center">
                              <div className="col">
                                 <img src="https://static.igem.wiki/teams/5247/engineering-cycle/cas12-nikase.webp"/>
                              </div>
                              <div className="col">
                                 <img src="https://static.igem.wiki/teams/5247/engineering-cycle/cas12-nikase-close-up.webp"/>
                              </div>
                           </div>
                           <figcaption>
                           <div className="row align-items-center">
                                 <div className="col">
                                    <b>Figure 5:</b> Schematic representation of Cas12a (PDB code: 8SFH) visualized in ChimeraX - the yellow circle highlights the position of arginine (R) (1226th amino acid in the primary structure) which, when replaced by an alanine (A), converts the Cas12a endonuclease into an nCas12a nickase
                                 </div>
                                 <div className="col">
                                    <b>Figure 6:</b> Close-up of Cas12a (PDB code: 8SFH) - arginine (R) (1226th amino acid in the primary structure) is colored purple
                                 </div>
                           </div>
                           </figcaption>
                        </figure>
                        
                        <p>
                           Based on these findings, two key decisions emerged. First, recognizing the structural and mechanistic similarities between Fanzor and Cas12 endonucleases, we decided to explore CasX—a smaller Cas12-related endonuclease—as an additional candidate in our project. CasX shares many of the advantages of SpuFz1, such as a more compact structure compared to Cas9, making it ideal for applications requiring smaller editing systems. Secondly, we resolved to adapt the mutation strategy used to convert Cas12a into a nickase for both CasX and SpuFz1. By applying these learnings, we aimed to generate effective nickases from these endonucleases to further optimize the Prime Editing complex.
                        </p>
                        <InfoBox title="The rationale behind designing SpuFz1 and CasX Nickases" id="how-to-create-nickases-online-fast">
                           <details>
                              <summary>
                              The mutation strategy aimed to convert the endonucleases SpuFz1 and CasX into nickases by targeting specific positively charged amino acids, similar to R1226 in mutated to create a AsCas12a nickase, to disrupt their double-strand cleavage function while retaining single-strand cutting capability.
                              </summary>
                              <p>
                                 In our project, we set out to engineer the endonucleases SpuFz1 and CasX into nickases, a process that required a more targeted approach than random mutagenesis due to the time and financial constraints of our project. Random mutagenesis, while a possible strategy, would have required an extensive scope, making it difficult to achieve meaningful results within our timeframe. As a result, we aimed to identify specific mutational candidates that would allow for a more focused and efficient approach.
                              </p>
                              <p>
                     	         One strategy we explored was finding an endonuclease with structural and mechanistic similarities to SpuFz1 and CasX, for which a successful precedent existed in converting an endonuclease into a nickase. After studying the phylogenetic relationships of SpuFz1 and CasX, we identified AsCas12a, an endonuclease with a similar sequential DNA cleavage mechanism. Importantly, there was already a known example where AsCas12a had been engineered into a nickase through a single mutation—specifically, the mutation of arginine 1226. This provided a strong foundation for us to develop a similar strategy for SpuFz1 and CasX.
                              </p>
                              <p>
                                 We hypothesized that the role of arginine 1226 in the sequential cleavage mechanism of AsCas12a was to coordinate the DNA strands during the cutting process. AsCas12a performs a sequential cut, where the RuvC domain first cleaves the non-target strand, and the TNB (NUC) domain helps guide the target strand into the RuvC domain for cleavage (Fig. 7). We suspected that arginine 1226 could play a key role in this process by coordinating the DNA due to its long, positively charged side chain. If removing or mutating this arginine disrupts the sequential cut, it would suggest that the arginine helps guide the second strand into the RuvC domain.
                              </p>
                              <p>
                                 Structurally, we observed that arginine 1226 protrudes from the NUC domain of AsCas12a and is oriented toward the RuvC domain (Fig. 8). This positioning led us to hypothesize that the arginine helps coordinate the DNA strand as it moves into the RuvC domain for cutting. Based on this observation, we speculated that the mutation of arginine 1226 disrupts this coordination, preventing the full double-strand cut and effectively converting AsCas12a into a nickase.
                              </p>
                              <figure>
                                 <div className="row align-items-center">
                                    <div className="col">
                                       <img src="https://static.igem.wiki/teams/5247/engineering-cycle/ascas12a-nuc-domain.webp"/>
                                    </div>
                                    <div className="col">
                                       <img src="https://static.igem.wiki/teams/5247/engineering-cycle/ascas12a-nuc-domain-close-up.webp"/>
                                    </div>
                                 </div>
                                 <figcaption>
                                    <div className="row align-items-center">
                                       <div className="col">
                                          <b>Figure 7:</b> AsCas12a (PDB code: 8SFH) visualized in ChimeraX. The NUC domain (TNB) is colored purple and is attached to the RuvC domain. The DNA strand is colored orange.
                                       </div>
                                       <div className="col">
                                          <b>Figure 8:</b> Close-up of NUC domain (colored purple) of AsCas12a(PDB code: 8SFH) - the arginines (R) (1226th amino acid in the primary structure) is colored yellow. Its positively charged side chain is oriented towards the RuvC domain, as well as the DNA strand fixated in the RuvC domain.
                                       </div>
                                    </div>
                                 </figcaption>
                              </figure>
                              <p>
                                 We then applied this structural insight to SpuFz1 and CasX, searching for positively charged amino acids with long side chains, similar to arginine 1226, that were positioned at the interface between the NUC and RuvC domains. We specifically looked for amino acids that protruded from the NUC domain and oriented toward the RuvC domain, mirroring the structural role of arginine 1226 in AsCas12a. These amino acids became our mutational targets, allowing us to design a strategy to convert SpuFz1 and CasX into nickases by disrupting their ability to make double-strand cuts, while preserving their functionality for single-strand cuts. The amino acids we identified in SpuFz1 are the 564th and the 568th arginine located in its NUC domain. For CasX we identified the 904th arginine as a promising candidate.
                              </p>
                           </details>
                        </InfoBox> 
                        <H4 text="Build" id="build-head"/>
                        <p>
                           We structurally analyzed CasX and SpuFz1, as well as the known AsCas12a nickase, using Chimera. Our objective was to understand why the specific amino acid substitution converted AsCas12a into a nickase. We then identified analogous amino acids in SpuFz1 (Fig. 7 and Fig. 8) and CasX (Fig. 9 and Fig. 10) that might play a similar role, allowing us to design new mutation candidates for our project. After designing these new mutation candidates, we modeled them using AlphaFold to predict their 3D structures and assess their potential effectiveness.
                        </p>
                        <figure>
                           <div className="row align-items-center">
                              <div className="col">
                                 <img src="https://static.igem.wiki/teams/5247/engineering-cycle/casx-nikase.webp"/>
                              </div>
                              <div className="col">
                                 <img src="https://static.igem.wiki/teams/5247/engineering-cycle/casx-nikase-close-up.webp"/>
                              </div>
                           </div>
                           <figcaption>
                           <div className="row align-items-center">
                                 <div className="col">
                                    <b>Figure 9:</b> Schematic representation of PlmCasX (PDB code: 7WAZ) in ChimeraX - the yellow circle highlights the position of arginine (R) (904th amino acid in the primary structure) and glutamine (Q) (907th amino acid in the primary structure), which, when replaced by an alanine (A), convert the endonuclease into a nickase, according to our hypothesis
                                 </div>
                                 <div className="col">
                                    <b>Figure 10:</b> Close-up of PlmCasX (PDB code: 7WAZ) - arginine (R) (904th amino acid in the primary structure) and glutamine (Q) (907th amino acid in the primary structure) are purple in color
                                 </div>
                           </div>
                           </figcaption>
                        </figure>

                        <figure>
                           <div className="row align-items-center">
                              <div className="col">
                                 <img src="https://static.igem.wiki/teams/5247/engineering-cycle/spufz-nikase.webp"/>
                              </div>
                              <div className="col">
                                 <img src="https://static.igem.wiki/teams/5247/engineering-cycle/spufz-nikase-close-up.webp"/>
                              </div>
                           </div>
                           <figcaption>
                           <div className="row align-items-center">
                                 <div className="col">
                                    <b>Figure 11:</b> Schematic representation of SpuFz1 (PDB code: 8GKH) in ChimeraX - the yellow circle highlights the position of the two arginines (R) (564th and 568th amino acid in the primary structure), which, when replaced by an alanine (A), transform the endonuclease into a nickase according to our hypothesis
                                 </div>
                                 <div className="col">
                                    <b>Figure 12:</b> Close-up of SpuFz1 (PDB code: 8GKH) - the two arginines (R) (564th and 568th amino acid in the primary structure) are purple in color
                                 </div>
                           </div>
                           </figcaption>
                        </figure>
                        <H4 text="Test" id="test-head"/>
                        <p>
                           To validate our approach, we conducted an interview with <a onClick={() => goToPagesAndOpenTab('saito', '/human-practices')}> Makoto Saito </a>, the lead author of the main Fanzor paper. Given his expertise, there was no better person to consult on this topic. We presented our project and our strategy for creating nickases, and he found our approach to be very plausible. He confirmed that the zinc finger mutation is likely structurally critical and agreed that our new strategy, based on the precedent with AsCas12a, was more promising. This conversation gave us confidence that we were on a good track.
                        </p>
                        <H4 text="Learn" id="learn-head"/>
                        <p>
                           From this iteration, we gained several key insights. First, our initial understanding of the cutting mechanism used by SpuFz1—based on the assumption that it contained two active centers, like Cas9, each cutting a DNA strand—was incorrect. We discovered that SpuFz1 operates differently, with the RuvC domain cutting the non-target strand and the TNB domain assisting by guiding the target strand into the RuvC domain for sequential cleavage. This shift in understanding allowed us to refine our approach, moving away from deactivating an active site to focusing on the sequential cutting mechanism.
                        </p>
                        <p>
                           Additionally, we found that Fanzor endonucleases, like SpuFz1, share a significant phylogenetic relationship with Cas12 endonucleases, which have a similar single-site cutting mechanism. This connection, along with the precedent of converting Cas12a into a nickase through the substitution of a single amino acid in the TNB domain, provided us with a clear strategy for converting SpuFz1 and CasX into nickases. The similarity in cutting mechanisms between Fanzor and Cas12 proteins reinforced the viability of this approach.
                        </p>
                        <p>
                           This iteration led us to incorporate CasX, a smaller Cas12-related endonuclease, into our project. CasX offers the same advantages as SpuFz1, such as a compact structure, making it ideal for applications that require smaller editing systems. Additionally, we adapted the mutation strategy used to convert Cas12a into a nickase for both CasX and SpuFz1, guiding our future work in optimizing the Prime Editing complex.
                        </p>
                        
                     </p>
                  </div>
                  <div className="box" >
                     <p id="nic5">
                        <H3 text="Ongoing: In Vitro Cleavage Assays" id="nic5head"/>
                        <H4 text="Design" id="design-head"/>
                        <p>
                           In this iteration, our focus shifted to testing whether our mutation candidates had successfully converted the endonucleases into functional nickases. To do this, we adapted an existing assay that had been originally designed to determine whether mutated endonucleases exhibited nickase activity<TabScrollLink tab="tab-nickase" num="1" scrollId="desc-1"/>. We tailored this assay to fit our specific needs, allowing us to accurately assess the properties of our mutated proteins in the lab. The key question was whether the mutations had rendered the proteins dysfunctional, left them as endonucleases, or successfully converted them into nickases.
                        </p>
                        <H4 text="Build" id="build-head"/>
                        <p>
                           We started off by amplification of our nickase candidates, ordered as gene syntheses, to add restriction sites. We then facilitated restriction cloning of the amplificates into an E. coli protein expression vector provided by the laboratory of or PI Kristian Müller. We subsequently transformed E. coli with the gene fragments of our nickase candidates for CasX and SpuFz. However, the transformant cells did not grow, leading us to suspect that the plasmid backbone we received maybe impaired in some way. Given the timeline, we were not able to complete the testing of our nickase candidates. Our current steps involve troubleshooting regarding the restriction cloning and continuing with protein expression and purification once the issue is resolved.
                        </p>
                        <H4 text="Test" id="test-head"/>
                        <p>
                           The next phase of our plan, once we overcome the current issues with cloning and successfully overexpress our nickase candidates, would involve conducting an in vitro plasmid cleavage assay (Fig. 13). In this assay, the purified nickases would be combined with their respective guide RNAs and a supercoiled test plasmid. The guide RNAs would direct the nickases to the target sequence on the plasmid. Depending on the results, the plasmid would remain supercoiled if untouched, become relaxed if nicked, or be linearized if cut by an endonuclease. To analyze these outcomes, we would perform gel electrophoresis, where the different conformations of the plasmid (supercoiled, relaxed, or linearized) would migrate differently through the gel. Supercoiled plasmids would migrate the furthest, relaxed plasmids would move the slowest, and linearized plasmids would fall between these two. As controls, we would have used the plasmid in its uncut form, nicked by nCas9 and digested using a restriction enzyme.
                        </p>
                        <H4 text="Learn" id="learn-head"/>
                        <p>
                           If we could have proceeded with the nickase assays, the readout would allow us to determine whether the tested proteins function as nickases, endonucleases, or remain inactive.
                        </p>
                        <div className="row align-items-center">
                           <figure>
                              <img src="https://static.igem.wiki/teams/5247/engineering-cycle/nickase-assay.webp" style={{height:"75%", width:"75%"}}/>
                              <figcaption>
                                 <b>Figure 13:</b> Theoretical gel electrophoresis results for our nickase assay. Lanes 1 and 8 represent molecular weight ladders, which provide size markers for the plasmid fragments. Lane 2 contains the untreated reporter plasmid, which remains supercoiled and travels the farthest through the gel. Lane 3 serves as a positive control, containing nCas9, gRNA, and the reporter plasmid. The nCas9 nickase nicks the plasmid, relaxing its structure, and as a result, the relaxed circular plasmid moves slower than the supercoiled form. Lane 4 acts as a negative control, containing a restriction enzyme and the reporter plasmid. The enzyme fully cuts the plasmid, linearizing it, and this linear form moves slower than the supercoiled plasmid but faster than the relaxed circular form. Lane 5 includes CasX and the reporter plasmid without gRNA, meaning no cleavage occurs, leaving the plasmid in its supercoiled state, which migrates similarly to the untreated plasmid in lane 2. Lane 6 contains CasX, gRNA, and the reporter plasmid, resulting in full cleavage and plasmid linearization, causing it to migrate similarly to the linear plasmid in lane 4. Finally, lane 7 includes our nickase candidate (either CasX or SpuFz1), gRNA, and the reporter plasmid. Ideally, the candidate would nick the plasmid, resulting in a relaxed circular form that moves similarly to the nicked plasmid in lane 3.
                              </figcaption>
                           </figure>
                        </div>
                     </p>
                  </div>
                  <div className="box" >
                     <p id="nic6">
                        <H3 text="Ongoing: SpuFz1 expression in Yeast" id="nic6head"/>
                        <H4 text="Design" id="design-head"/>
                        <p>
                           When talking to <a onClick={() => goToPagesAndOpenTab('saito', '/human-practices')}> Makoto Saito </a>, he told us that expressing SpuFz1 in E. coli did not work for him. He advised us to instead establish a yeast expression system. Since none of us had any experience with using yeast for protein production, we reached out to <a onClick={() => goToPagesAndOpenTab('nberelsmann', '/human-practices')}> Nils Berelsmann </a> at the faculty of chemistry at our university. He was able to provide us with a yeast expression strain as well as the corresponding expression vector. Because we were strongly restricted by time at that point, we then asked <a onClick={() => goToPagesAndOpenTab('hakan', '/human-practices')}> Hakan Soytürk </a> from the biological faculty for help and he offered to facilitate transformation and selection of positive Yeast transformants for us.
                        </p>
                        <H4 text="Build" id="build-head"/>
                        <p>
                           The workflow for cloning SpuFz1 amplificates into the pPIC9K yeast vector was similar to the cloning into the E. coli expression vector. After multiple attempts of transformations and colony PCRs we found positive clones for two of the nickase variants. Hakan transformed them into the yeast strain for us, but no colonies formed, indicating unsuccessful transformation. Due to time constraints, we were not able to repeat the cloning. However, testing our SpuFz1 and also CasX nickase candidates and eventually using them for prime editing.
                        </p>
                     </p>
                  </div>
                  <div className='row align-items-center'>
                        <div className='col'>
                           <TwoLinePDF link='https://static.igem.wiki/teams/5247/pdfs/cloning-strategy-spufz1.pdf' name="cloning-strategy-spufz1.pdf"/>
                        </div>
                        <div className='seperator-2 col-2'>
                        </div>
                        <div className='col'>
                           <TwoLinePDF link='https://static.igem.wiki/teams/5247/pdfs/cloning-strategy-plmcasx.pdf' name="cloning-strategy-plmcasx.pdf"/>
                        </div>
                     </div>
                     <div className='row align-items-center'>
                        <div className='col'>
                           <PDF link='https://static.igem.wiki/teams/5247/pdfs/cloning-strategy-cas9.pdf' name="cloning-strategy-cas9.pdf'"/>
                        </div>
                     </div>
                  </div>
                  <Section title="References" id="references">
                     <EngNicksources/>
                  </Section>
                  <br/>
                  <div className="row ">
                     <div className="col">
                     <div className="left"><ButtonOneEngineering label="Previous" open="pegrna" scrollToId="pegrna-header"/></div>
                     </div>
                     <div className="col button-left">
                        <div className="right"><ButtonOneEngineering label="Next" open="delivery" scrollToId="delivery-header"/></div>
                     </div>
                  </div>
               </section>
            </div>

            <div className="enginneeringtab" id="tab-delivery" style={{display: "none"}}>
               <section id="Delivery sec" >
                  <div className="eng-box box" >
                     <H2 id="delivery-header" text="Delivery"></H2>
                     <p>The design path of our lipid nanoparticle (LNP) for mRNA delivery underwent multiple cycles of research and discussion, marked by important decision points and learnings along the way. By ongoing further improvement, we designed our lungs-specific LNP called AirBuddy with improved stability aspects, becoming more precise in the delivery of our therapeutic cargo LNP by LNP.</p>
                      <img src="https://static.igem.wiki/teams/5247/delivery/airbuddy.webp" style={{maxHeight: "80pt"}}/>  
                  </div>
                  <div className="box" >
                     <p id="del1">
                     <H3 text="Iteration 1 - AVVs vs LNPs" id="del1head" /> 
                        <p>Initially, this project part started with a discussion with <a onClick={() => goToPagesAndOpenTab('kristian', '/human-practices')}> Prof. Dr. Krisitan Müller</a>, PI of our team with expertise in Adeno-associated viruses (AAVs), focusing on whether to pursue LNPs or AAVs for mRNA delivery. The deciding factor leaned towards LNPs, as they offered a significant advantages including less immunogenic potential<TabScrollLink tab="tab-delivery" num="1" scrollId="desc-1"/> and bigger loading capacity<TabScrollLink tab="tab-delivery" num="2" scrollId="desc-2"/>. LNPs loading capacity depends on various factors, but in general they offer a bigger cargo size compared to 4.7 kb for AVVs<TabScrollLink tab="tab-delivery" num="3" scrollId="desc-3"/>. This allows the delivery of bigger mRNA constructs compared to AAVs, which is needed for our Prime Editing construct.</p>
                        <p><a onClick={() => goToPagesAndOpenTab('weber', '/human-practices')}>Prof. Wolf-Michael Weber and Dr. Jörg Große-Onnebrink</a> from the UKM in Münster were our first point of contact for the development of our LNP for CFTR treatment. Moreover, <a onClick={() => goToPagesAndOpenTab('radukic', '/human-practices')}>Dr. Marco Radukic </a>form Bielefeld University provided us with a very useful cargo, namely minicircle DNA carrying the EYFP gene from <a href="https://www.plasmidfactory.com/custom-dna/minicircle-dna/" title="PlasmidFactory" >PlasmidFactory</a> as a positive control for our experiments. He also helped us establish protocols for LNP synthesis and LNP transfection in our lab.</p>
                     </p>
                  </div>
                  <div className="box" >
                     <p id="del2">
                     <H3 text="Interation 2 - Cayman LNP" id="del2head" /> 
                        In the first experimental phase, LNPs from <strong>Cayman Chemical LNP Exploration Kit (LNP-102)</strong> consisting of SM-102, 1,2-DSPC, cholesterol, and DMG-PEG(2000)<TabScrollLink tab="tab-delivery" num="4" scrollId="desc-4"/> were tested with mRNA encoding fluorescent protein to evaluate their transfection efficiency. However, the results showed low transfection efficiency, and the particles did not show specificity for the lungs, which was a critical requirement for the project. This led the team to reconsider the choice of the LNP.
                     </p>
                     <figure> 
                         <img src="https://static.igem.wiki/teams/5247/delivery/cayman-lnp-freigestellt.webp" alt="Cayman LNP"/> 
                         <figcaption> 
                          <b>Figure 1.</b> 
                          Schematic view of LNP-102 from Cayman Chemical
                        </figcaption> 
                     </figure> 
                  </div>
                  <div className="box" >
                     <p id="del3">
                        <H3 text="Interation 3 - Corden LNP" id="del3head" /> 
                        In the next phase, we chose to use a new LNP formulation, namely the <strong>LNP Starter Kit #2</strong><TabScrollLink tab="tab-delivery" num="5" scrollId="desc-5"/> of <a onClick={() => goToPagesAndOpenTab('corden', '/human-practices')}>Corden Pharma</a>, because it offered several advantages over the initial option. The key benefit of this new LNP lies in the use of DOTAP, a cationic lipid that enhances interaction with negatively charged cell membranes in the lungs, improving cellular uptake efficiency. While SM-102 in the Cayman LNP-102 is effective for systemic delivery, it lacks the same specificity for lung tissue. Additionally, Corden Pharma’s plant-based BotaniChol® prevents animal-sourced contamination and helps address the global lipid shortage for vaccine production. mPEG-2000-DSPE provides superior stability and reduces immune system activation over time, making it particularly suitable for pulmonary delivery.  This made the new formulation a better choice for safely and effectively targeting lung tissue, especially in delivering therapies for CFTR-related diseases. During this time, the team encountered a paper on capsaicin-chitosan nanoparticles, which explored its use in targeted delivery and higher transfection efficiency. However, after further investigation and consultation of <a onClick={() => goToPagesAndOpenTab('kolonkofirst', '/human-practices')}>Dr. Katharina Kolonko</a>, it was determined that capsaicin was not suitable for our planned pulmonary application. 
                     </p>
                     <figure> 
                         <img src="https://static.igem.wiki/teams/5247/delivery/corden-lnp-freigestellt.webp" alt="Corden LNP"/> 
                         <figcaption> 
                          <b>Figure 2.</b> 
                          Schematic view of LNP #2 from Corden Pharma with DOTAP as cationic lipid, DSPC as phospholipid and mPEG-200-DSPE as PEG lipid.
                        </figcaption> 
                     </figure> 
                  </div>
                  <div className="box" >
                     <p id="del4">
                     <H3 text="Interation 4 - Spray-dried SORT LNP called Airbuddy" id="del4head" /> 
                     The next design iteration incorporated the insights from Wang's LNP work for building upon SORT principles to make the nanoparticles lung-specific<TabScrollLink tab="tab-delivery" num="6" scrollId="desc-6"/>. The main components include DMG-PEG 2000, cholesterol, DOPE and DOTAP as phospholipids and cationic lipids such as 4A3-SC8. In our LNP development, we carefully considered the use of PEG. While PEG can improve stability, it can also reduce cellular uptake and induce immune responses, necessitating a balanced approach to its inclusion<TabScrollLink tab="tab-delivery" num="7" scrollId="desc-7"/>.
                     <Collapsible id="Col1" open={false} title="Ambivalence of PEG and our implementation">
                        <p>
                        <H4 text="What is PEG and why is it important for LNPs?" id="text" /> 
                        Polyethylene glycol (PEG) is an essential component in the formulation of lipid nanoparticles (LNPs), which are widely used in drug delivery systems, particularly for mRNA-based therapies like vaccines. PEG-lipids are hybrid molecules consisting of a hydrophilic PEG chain attached to a hydrophobic lipid anchor. This unique structure enables PEG-lipids to interact effectively with both aqueous environments and lipid structures, such as cell membranes and lipid nanoparticles themselves. 
                        <p>PEGylation—attaching PEG to lipids—provides numerous benefits. It increases the stability of LNPs by forming a protective outer layer, preventing aggregation, extending circulation time in the bloodstream, and reducing immune system detection. These advantages are critical in ensuring that the LNPs reach their target cells and deliver the therapeutic payload effectively. </p>
                        <H4 text="Why is PEG relevant for LNPs in mRNA delivery?" id="text" /> 
                        PEG improves the pharmacokinetics of LNPs by extending their systemic circulation time, which is crucial for therapies like mRNA vaccines, where the nanoparticles must remain in the bloodstream long enough to reach their target cells. Additionally, PEG-lipids can reduce the size of LNPs, enhancing their ability to penetrate cell membranes and deliver the therapeutic material efficiently. However, a balance must be struck. Increasing PEG content can lead to smaller, more stable particles, but it may also reduce intracellular delivery and protein expression. Therefore, while PEG boosts circulation and stability, too much can hinder therapeutic effectiveness.
                        <H4 text="Cytotoxicity and mPEG-2000-DSPE" id="text" /> 
                        One challenge with PEGylation is the potential for immune responses, such as the <i>accelerated blood clearance</i> (ABC) phenomenon, where repeated exposure to PEGylated particles leads to faster clearance by the immune system. There are also risks of hypersensitivity reactions like <i>complement activation-related pseudoallergy</i> (CARPA). Thus, selecting the right PEG-lipid type is essential to mitigate these risks.
                        <p>We collaborated with <a onClick={() => goToPagesAndOpenTab('corden', '/human-practices')}>Corden Pharma</a>, a specialist in LNP technologies, to address these concerns. Based on their recommendations, we opted for <strong>mPEG-2000-DSPE</strong> as our PEG-lipid of choice. This variant minimizes cytotoxicity while providing excellent stability and circulation time. It has also proven effective in reducing immune-related side effects while preserving the integrity and performance of our nanoparticles. </p>
                        <H4 text="DMG-PEG2000 vs mPEG-2000-DSPE" id="text" /> 
                        While mPEG-2000-DSPE has traditionally been used for stabilizing LNPs and enhancing delivery efficiency, we decided to incorporate DMG-PEG2000 into our SORT LNP-based AirBuddy due to its superior properties. DMG-PEG2000 offers better biodegradability and enhanced stability in pulmonary applications. Unlike mPEG-2000-DSPE, which tends to accumulate in the body and may lead to immune activation over time, DMG-PEG2000 is known for its faster clearance and reduced potential for long-term toxicity. For lung-specific delivery, where stability and safety are critical, DMG-PEG2000 ensures that the nanoparticles remain stable long enough to deliver the therapeutic material effectively, but also degrade at a rate that minimizes unwanted immune responses. This makes DMG-PEG2000 a more suitable choice for therapies targeting CFTR-related diseases, where precise and safe delivery to the lungs is essential for treatment success. 
                        <p>Details about the biosafety aspects of our LNP can be read <a onClick={() => goToPageAndScroll ('sort-lnp-and-cytotoxicity', '/safety')}> here </a>. </p>
                        
                        <H4 text="Conclusion" id="text" /> 
                        We use DMG-PEG2000 in our SORT LNP-based AirBuddy because of its superior biodegradability, enhanced stability, and reduced risk of immune system activation. By building on insights from experts and incorporating principles from Wang’s LNP work, we’ve tailored our nanoparticles for lung-specific delivery. This choice ensures that our formulations remain stable long enough to deliver the therapeutic payload effectively while minimizing potential long-term toxicity. This balance is crucial for pulmonary applications, where DMG-PEG2000 outperforms alternatives like mPEG-2000-DSPE, making it the ideal choice for treating CFTR-related lung diseases. 
                        </p>
                     </Collapsible>
                     <p>DMG-PEG2000 of the SORT LNP offers better biodegradability and enhanced stability in pulmonary applications - it is known for its faster clearance and reduced potential for long-term toxicity. To ensure we addressed this issue, cytotoxicity tests were performed in addition to the determination of physical properties in cooperation with the <a onClick={() => goToPagesAndOpenTab('biophysik', '/human-practices')}>Physical and Biophysical Chemistry working group of Bielefeld University</a> to characterize the LNPs. More details about the composition of the SORT LNPs and function of the components can be read below.</p>
                     <figure> 
                         <img src="https://static.igem.wiki/teams/5247/delivery/sort-lnp-freigestellt.webp" alt="AirBuudy"/> 
                         <figcaption> 
                          <b>Figure 3.</b> 
                          Schematic view of our lung-specific SORT LNP called AirBuddy.
                        </figcaption> 
                     </figure> 
                     <Collapsible id="Col2" open={false} title="Composition of our SORT LNP called Airbuddy // LNP Handbook Cooperation">
                        <H4 text="Components of AirBuddy" id="text" /> 
                        <H5 text="Ionizable Lipid" id="text" />
                              <p>The primary ingredient, 4A3-SC8 or MC3, are ionizable cationic lipids that forms the core of the LNP. Ionizable cationic lipids become positively charged in acidic environments, such as when a pH change occurs for example in acidic buffers or in the endosome. This allows them to bind to negatively charged nucleic acids and form protective capsules around it. In the endosome these lipids facilitate endosomal escape through electrostatic interactions between the LNPs and the endosomal or cellular membranes.</p>
                        <H5 text="Helper Lipids" id="text" /> 
                              <p>DOTAP (Dioleoyltrimethyl-ammonium propane) is a cationic lipid that makes up 50 % of the total molar lipid ratio. It plays a crucial role in binding to the negatively charged surface of lung epithelial cells. This enhances transfection efficiency and helps make the LNP formulation more lung-specific, improving targeted delivery. The neutral helper lipid DOPE (Dioleoylphosphatidylethanolamine) enhances endosomal escape by fusing with the endosomal membrane and improves transfection efficiency.</p>                            
                        <H5 text="Sterol" id="text" />
                              <p>Cholesterol, is an important cationic lipid, providing structural stability, fluidity and permeability to the LNPs, thereby improving their overall transfection efficiency. </p>
                        <H5 text="PEGylated Lipids" id="text" />
                              <p>DMG-PEG (Dimyristoylglycerin-polyethyleneglycol) is an important component by improving the LNP stability and preventing aggregation of the LNPs.  </p>
                        <H4 text="Production Methods" id="text" /> 
                        <H5 text="LNP Assembly" id="text" />
                            <p>Our LNP can be formulated using various methods depending on the scale of production, including pipette mixing, vortex mixing, or microfluidic mixing. For cargo protection the mRNA can be mixed with chitosan for stability improvement before adding with the LNP components. After mixing the lipids with mRNA in carefully controlled ratios, the mixture is typically dialyzed to remove organic solvents like ethanol and citrate buffer. The choice of lipid composition and preparation method influences the tissue-targeting capabilities of the LNPs, allowing for selective delivery to organs like the liver, lungs, or spleen. For more detailed information on formulation methods and lipid selection, refer to our LNP Handbook deigned in <a onClick={() => goToPageAndScroll ('handbook', '/human-practices')}> cooperation with iGEM Team Linköping </a> and others.</p>
                            <p>Click this Button to gain the LNP Handbook</p>
                        <DownloadLink url="https://static.igem.wiki/teams/5387/liposomes-handbook.pdf" fileName="liposomes-handbook.pdf" /> 
                        <H5 text="Spray drying Procedure" id="text" />
                            <p>By combining these components with the spray drying method from <a onClick={() => goToPageAndScroll ('rnhale', '/human-practices')}> RNhale </a> we offer a versatile and efficient method for delivering mRNA therapeutics to the lung, paving the way for gene therapy, especially our Prime Guide. The effective delivery of the prime editing complex is a crucial point in our project. </p>
                        <H5 text="Storage" id="text" />
                           <p>The final LNP solution can be stored at 4 °C for a few days. It is recommended to use the formulated LNPs as soon as possible to maintain consistent results. Storage at RT is not recommended. Storage at freezing temperatures is also not recommended unless optimized cryoprotectants are used.</p>

                     </Collapsible>
                     <p>The final innovation for our LNP to become <strong>AirBuddy</strong> came through consultation with Benjamin Winkeljann from <a onClick={() => goToPagesAndOpenTab('rnhale', '/human-practices')}> RNhale</a>, where the use of spray-drying techniques was discussed. Spray-drying the LNPs, instead of using traditional methods, helps improve stability and eco-friendliness of the product<TabScrollLink tab="tab-delivery" num="8" scrollId="desc-8"/>. Unfortunately, we were not in time for our samples to be delivered to RNhale for spray-drying before the wiki freeze, but we have already scheduled the transfer. Instead, the discussion with <a onClick={() => goToPagesAndOpenTab('moorlach', '/human-practices')}>Benjamin Moorlach</a>, chitosan expert working at FH Bielefeld, provided new ideas for improvement by <strong>complexing the mRNA with chitosan</strong> to improve the stability of the cargo during spray drying and nebulization. The positive effect of RNA chitosan complexing for opimized LNP delivery could be confimed in our lab. In conclusion, we created a stable LNP for efficient delivery of mRNA therapeutics to the lungs since the successful delivery of the prime editing complex via inhalation is key to our project.  </p>
                     <figure> 
                        <img src="https://static.igem.wiki/teams/5247/delivery/big-plan-inhalation-teil-del.webp" alt="Flow DEL"/> 
                        <figcaption> 
                        <b>Figure 4. </b> 
                        Application stategy - AirBuddy is inhaled by the patient, enabling uptake of PrimeGuide in lung epithelial cells via endocytosis. 
                        </figcaption> 
                     </figure> 

                     </p>
                  </div>
                  <div className="box" >
                     <p id="del5">
                     <H3 text="Outlook" id="del5head" /> 
                     Ultimately, through continuous cycles of experimentation, feedback, and optimization, a LNP formulation called AirBuddy was designed using SORT LNPs and a spray-drying process, achieving lung specificity and improved safety. We also want to state that for our LNP is further room for improvement. Intensive research led us to the realization that, among other modifications, <strong>antibody conjugation</strong> as a surface modification of our LNP for cell type-specific administration, more specifically club cells<TabScrollLink tab="tab-delivery" num="9" scrollId="desc-9"/> and ionocytes<TabScrollLink tab="tab-delivery" num="10" scrollId="desc-10"/> as most CFTR-expressing lung epithelial cells, would round off our most important aspect of precision. 
                     </p>
                  </div>
                  <Section title="References" id="references">
                     <EngDelsources/>
                  </Section>
                  <br/>
                  <div className="row">
                     <div className="col">
                     <div className="left"><ButtonOneEngineering label="Previous" open="nickase" scrollToId="nickase-header"/></div>
                     </div>
                     <div className="col button-left">
                     </div>
                  </div>
               </section>
            </div>
            
          </div>
  
        </div>
      </>
    );
  } 

  

export function EngineeringCycleTab(){
    return(
 <svg className="rotate-linear-infinite"
    width="100%"
    height="100%"
    viewBox="0 0 133 133"
    id="svg25"
    xmlns="http://www.w3.org/2000/svg">
   <defs
      id="defs1">
     </defs>
   <g
      id="Layer_2"
      data-name="Layer 2"
      style={{strokeWidth:"6",strokeDasharray:"none"}}>
     <g
        id="Plasmid"
        style={{strokeWidth:"6",strokeDasharray:"none"}}>
       <g
          id="g25"
          transform="translate(7.500978,3.0504898)">
            <a  typeof="button" className="svg-button" onClick={openElement({elementToOpen: "designing", classToHide: "cycletab"})}>
         <path
            className="cls-7"
            d="m 42.05,115.59 c 27.77,9.19 57.83,-4.79 69.76,-32.23"
             id="path22"
            style={{stroke:"#f4cc1e",strokeWidth:"15",strokeDasharray:"none",strokeOpacity:"1"}} />
            </a>
       </g>
       <g
          id="g26"
          transform="translate(8.0019699,2.8418223)"
          style={{strokeWidth:"6",strokeDasharray:"none"}}>  
         <polygon
            className="cls-13"
            points="112.07,83.36 110.94,76.27 117.65,78.84 "
             id="polygon25"
            style={{fill:"#850f78",fillOpacity:"1",strokeWidth:"6",strokeDasharray:"none"}}
            transform="matrix(2.9806259,0,0,2.9806259,-225.43722,-156.45123)" />
            <a  typeof="button" className="svg-button" onClick={openElement({elementToOpen: "learning", classToHide: "cycletab"})}>
            <path
              className="cls-12"
              d="M 114,78.55 C 123.45,50.86 110,20.75 82.66,8.6"
              id="path25"
              style={{strokeWidth:"15",strokeDasharray:"none",stroke:"#850f78",strokeOpacity:"1"}} /> 
           
         <text
            style={{fontSize:"17.3333px",lineHeight:"0",fontFamily:"Arial",fill:"var(--offblack)",fillOpacity:"1",stroke:"none",strokeWidth:"15",strokeLinecap:"round",strokeLinejoin:"round",strokeDasharray:"none",strokeOpacity:"1",paintOrder:"fill markers stroke"}}
            id="text31"
            transform="translate(5.6902194,-0.11551883)"><textPath
             xlinkHref="#path25"
              id="textPath33">Learn<tspan
          id="tspan31" /></textPath></text>  </a>
       </g>
       <g
          id="g27"
          style={{strokeWidth:"6",strokeDasharray:"none"}}
          transform="translate(8.0019699,2.8418223)">
         <polygon
            className="cls-10"
             points="62.53,7.12 63.47,0 69.17,4.37 "
            id="polygon23"
             transform="matrix(2.7712263,0.58147548,-0.58147548,2.7712263,-96.587828,-39.748071)"
            style={{fill:"#a0a7f3",fillOpacity:"1",strokeWidth:"6",strokeDasharray:"none"}}
            inkscape:transform-center-x="3.6173751"
            inkscape:transform-center-y="5.1978852" />
            <a  typeof="button" className="svg-button" onClick={openElement({elementToOpen: "testing", classToHide: "cycletab"})}>
         <path
            className="cls-9"
            d="M 78.599111,7.5468264 C 43.820346,-2.6177588 13.956746,14.286046 4.2106281,46.368749"
            id="path23"
            style={{stroke:"#a0a7f3",strokeWidth:"15",strokeDasharray:"none",strokeOpacity:"1"}} />
         <text
            
            style={{fontSize:"17.3333px",lineHeight:"0",fontFamily:"Arial",fill:"var(--offblack)",fillOpacity:"1",stroke:"none",strokeWidth:"6",strokeLinecap:"round",strokeLinejoin:"round",strokeDasharray:"none",strokeOpacity:"1",paintOrder:"fill markers stroke"}}
            id="text28"
            
            transform="translate(-0.03023506,-5.9602336)"><textPath
            xlinkHref="#path23"
             id="textPath28">Test</textPath></text> </a>
       </g>
       <g
          id="g28"
          style={{strokeWidth:"6",strokeDasharray:"none"}}
          transform="translate(8.0019699,2.8418223)">
         <polygon
            className="cls-13"
            points="117.65,78.84 112.07,83.36 110.94,76.27 "
             id="polygon25-6"
            style={{fill:"#f57d22",fillOpacity:"1",strokeWidth:"6",strokeDasharray:"none"}}
            transform="matrix(-2.9650314,0.30449893,-0.30449893,-2.9650314,364.84067,249.28249)" />
            <a  typeof="button" className="svg-button" onClick={openElement({elementToOpen: "building", classToHide: "cycletab"})}>
          <path
            className="cls-11"
            d="M 2.6659753,50.953505 C -2.0956694,72.727915 10.936866,102.94273 36.656234,113.62834"
             id="path24"
            style={{strokeWidth:"15",strokeDasharray:"none",stroke:"#f57d22",strokeOpacity:"1"}} />
         <text
            
            style={{fontSize:"17.3333px",lineHeight:"0",fontFamily:"Arial",fill:"var(--offblack)",fillOpacity:"1",stroke:"none",strokeWidth:"15",strokeLinecap:"round",strokeLinejoin:"round",strokeDasharray:"none",strokeOpacity:"1",paintOrder:"fill markers stroke"}}
            id="text32"
            transform="translate(-5.7110315,1.7453243)"><textPath
             xlinkHref="#path24"
              id="textPath32">Build<tspan
    id="tspan32" /></textPath></text> </a>
       </g>
       <polygon
          className="cls-8"
          points="37.22,113.74 44.3,112.56 41.78,119.28 "
          id="polygon22"
          style={{strokeWidth:"6",strokeDasharray:"none",fill:"#f4cc1e",fillOpacity:"1"}}
          transform="matrix(2.8248588,0,0,2.8248588,-67.797781,-207.96977)" />
          <a  typeof="button" className="svg-button" onClick={openElement({elementToOpen: "designing", classToHide: "cycletab"})}>
       <text
          
          style={{fontSize:"17.3333px",lineHeight:"0",fontFamily:"Arial",fill:"var(--offblack)",fillOpacity:"1",stroke:"none",strokeWidth:"15",strokeLinecap:"round",strokeLinejoin:"round",strokeDasharray:"none",strokeOpacity:"1",paintOrder:"fill markers stroke"}}
          id="text29"
          transform="translate(8.4052921,8.8553334)"><textPath
          xlinkHref="#path22"
          id="textPath34">Design<tspan
          id="tspan29" /></textPath></text> </a>
     </g>
   </g>
   <a  typeof="button" className="svg-button" onClick={openElement({elementToOpen: "overview", classToHide: "cycletab"})}>
   <circle
     style={{opacity:"0.85",fill:"#e2dad7",fillOpacity:"1",strokeWidth:"15",strokeLinecap:"round",strokeLinejoin:"round",paintOrder:"fill markers stroke"}}
     id="path1"
     cx="67.916214"
     cy="63.214005"
     r="20" />
  <text
     style={{fontSize:"8px",lineHeight:"0",fontFamily:"Arial",opacity:"0.85",fill:"var(--offblack)",fillOpacity:"1",strokeWidth:"15",strokeLinecap:"round",strokeLinejoin:"round",strokeDasharray:"none",paintOrder:"fill markers stroke"}}
     x="50.929825"
     y="66.676674"
     id="text1">
      <tspan
       id="tspan1"
       x="50.929825"
       y="66.676674"
       style={{fontSize:"8px"}}>Overview</tspan></text> 
       </a>

 </svg>
 
    )
 }


